[openssl-commits] [openssl] master update

Rich Salz rsalz at openssl.org
Fri Oct 30 21:21:54 UTC 2015


The branch master has been updated
       via  b0700d2c8de79252ba605748a075cf2e5d670da1 (commit)
      from  87d9cafa332bd006086b56dc645c03fe7cfed654 (commit)


- Log -----------------------------------------------------------------
commit b0700d2c8de79252ba605748a075cf2e5d670da1
Author: Rich Salz <rsalz at akamai.com>
Date:   Tue Oct 27 15:11:48 2015 -0400

    Replace "SSLeay" in API with OpenSSL
    
    All instances of SSLeay (any combination of case) were replaced with
    the case-equivalent OpenSSL.
    
    Reviewed-by: Richard Levitte <levitte at openssl.org>

-----------------------------------------------------------------------

Summary of changes:
 CHANGES                               |   4 +
 apps/CA.com                           |  23 +-
 apps/CA.pl.in                         |   6 +-
 apps/openssl.c                        |   3 +-
 apps/s_server.c                       |   2 +-
 apps/speed.c                          |   8 +-
 apps/version.c                        |  14 +-
 crypto/bn/bn_lcl.h                    |  14 +-
 crypto/bn/bn_prime.h                  | 516 +++++++++++++++++-----------------
 crypto/bn/bn_prime.pl                 |  39 +--
 crypto/cversion.c                     |  22 +-
 crypto/des/Makefile                   |   5 +-
 crypto/des/des_ver.h                  |  73 -----
 crypto/des/ecb_enc.c                  |   1 -
 crypto/des/rpc_enc.c                  |   1 -
 crypto/engine/eng_cryptodev.c         |  10 +-
 crypto/engine/eng_openssl.c           |   2 +-
 crypto/lhash/lh_stats.c               |   2 +-
 crypto/lock.c                         |   4 +-
 crypto/rand/md_rand.c                 |  66 ++---
 crypto/rand/rand_err.c                |   4 +-
 crypto/rand/rand_lib.c                |   8 +-
 crypto/rsa/rsa_eay.c                  |   2 +-
 crypto/rsa/rsa_lib.c                  |   2 +-
 demos/easy_tls/easy-tls.c             |   2 +-
 demos/engines/ibmca/hw_ibmca.c        |   4 +-
 demos/engines/zencod/hw_zencod.c      |  12 +-
 demos/pkcs12/pkwrite.c                |   2 +-
 demos/sign/sign.c                     |   2 +-
 demos/ssl/cli.cpp                     |   4 +-
 demos/ssl/inetdsrv.cpp                |   2 +-
 demos/ssl/serv.cpp                    |   6 +-
 doc/apps/dhparam.pod                  |   2 +-
 doc/apps/enc.pod                      |   5 +-
 doc/apps/req.pod                      |   3 +-
 doc/apps/verify.pod                   |   2 +-
 doc/crypto/OPENSSL_VERSION_NUMBER.pod |   8 +-
 doc/crypto/RAND_set_rand_method.pod   |   8 +-
 doc/crypto/SSLeay_version.pod         |  70 -----
 doc/ssl/SSL_library_init.pod          |   6 +-
 e_os.h                                |  26 +-
 engines/e_capi.c                      |   2 +-
 engines/e_chil.c                      |   4 +-
 engines/e_gmp.c                       |   2 +-
 engines/e_ubsec.c                     |  12 +-
 include/openssl/crypto.h              |  24 +-
 include/openssl/dsa.h                 |   5 +-
 include/openssl/evp.h                 |   3 -
 include/openssl/rand.h                |   4 +-
 include/openssl/rsa.h                 |   4 +-
 include/openssl/ssl.h                 |  15 +-
 include/openssl/x509.h                |   3 +-
 test/recipes/80-test_ca.t             |   6 +-
 test/recipes/80-test_tsa.t            |   2 +-
 util/libeay.num                       |   8 +-
 55 files changed, 438 insertions(+), 651 deletions(-)
 delete mode 100644 crypto/des/des_ver.h
 delete mode 100644 doc/crypto/SSLeay_version.pod

diff --git a/CHANGES b/CHANGES
index a8629d8..86c572d 100644
--- a/CHANGES
+++ b/CHANGES
@@ -14,6 +14,10 @@
      also been removed.
      [Matt Caswell]
 
+  *) All instances of the string "ssleay" in the public API were replaced
+     with OpenSSL (case-matching; e.g., OPENSSL_VERSION for #define's)
+     [Rich Salz]
+
   *) The demo files in crypto/threads were moved to demo/threads.
      [Rich Salz]
 
diff --git a/apps/CA.com b/apps/CA.com
index 2c0d465..95925d3 100644
--- a/apps/CA.com
+++ b/apps/CA.com
@@ -10,29 +10,14 @@ $! At the end of that grab newreq.pem and newcert.pem (one has the key
 $! and the other the certificate) and cat them together and that is what
 $! you want/need ... I'll make even this a little cleaner later.
 $!
-$!
-$! 12-Jan-96 tjh    Added more things ... including CA -signcert which
-$!                  converts a certificate to a request and then signs it.
-$! 10-Jan-96 eay    Fixed a few more bugs and added the SSLEAY_CONFIG
-$!                 environment variable so this can be driven from
-$!                 a script.
-$! 25-Jul-96 eay    Cleaned up filenames some more.
-$! 11-Jun-96 eay    Fixed a few filename missmatches.
-$! 03-May-96 eay    Modified to use 'openssl cmd' instead of 'cmd'.
-$! 18-Apr-96 tjh    Original hacking
-$!
-$! Tim Hudson
-$! tjh at cryptsoft.com
-$!
-$!
-$! default ssleay.cnf file has setup as per the following
+$! default openssl.cnf file has setup as per the following
 $! demoCA ... where everything is stored
 $
-$ IF F$TYPE(SSLEAY_CONFIG) .EQS. "" THEN SSLEAY_CONFIG := SSLLIB:SSLEAY.CNF
+$ IF F$TYPE(OPENSSL_CONFIG) .EQS. "" THEN OPENSSL_CONFIG := SSLLIB:OPENSSL.CNF
 $
 $ DAYS   = "-days 365"
-$ REQ    = openssl + " req " + SSLEAY_CONFIG
-$ CA     = openssl + " ca " + SSLEAY_CONFIG
+$ REQ    = openssl + " req " + OPENSSL_CONFIG
+$ CA     = openssl + " ca " + OPENSSL_CONFIG
 $ VERIFY = openssl + " verify"
 $ X509   = openssl + " x509"
 $ PKCS12 = openssl + " pkcs12"
diff --git a/apps/CA.pl.in b/apps/CA.pl.in
index 5c8cdd0..a814ebf 100644
--- a/apps/CA.pl.in
+++ b/apps/CA.pl.in
@@ -16,11 +16,11 @@ if(defined $ENV{'OPENSSL'}) {
 
 my $verbose = 1;
 
-my $SSLEAY_CONFIG = $ENV{"SSLEAY_CONFIG"};
+my $OPENSSL_CONFIG = $ENV{"OPENSSL_CONFIG"};
 my $DAYS = "-days 365";
 my $CADAYS = "-days 1095";	# 3 years
-my $REQ = "$openssl req $SSLEAY_CONFIG";
-my $CA = "$openssl ca $SSLEAY_CONFIG";
+my $REQ = "$openssl req $OPENSSL_CONFIG";
+my $CA = "$openssl ca $OPENSSL_CONFIG";
 my $VERIFY = "$openssl verify";
 my $X509 = "$openssl x509";
 my $PKCS12 = "$openssl pkcs12";
diff --git a/apps/openssl.c b/apps/openssl.c
index 2b0425b..1fd3e73 100644
--- a/apps/openssl.c
+++ b/apps/openssl.c
@@ -217,8 +217,7 @@ static char *make_config_name()
     size_t len;
     char *p;
 
-    if ((t = getenv("OPENSSL_CONF")) != NULL
-        || (t = getenv("SSLEAY_CONF")) != NULL)
+    if ((t = getenv("OPENSSL_CONF")) != NULL)
         return BUF_strdup(t);
 
     t = X509_get_default_cert_area();
diff --git a/apps/s_server.c b/apps/s_server.c
index aa01d43..4848fbe 100644
--- a/apps/s_server.c
+++ b/apps/s_server.c
@@ -2719,7 +2719,7 @@ static int www_body(char *hostname, int s, int stype, unsigned char *context)
                      "HTTP/1.0 200 ok\r\nContent-type: text/html\r\n\r\n");
             BIO_puts(io, "<HTML><BODY BGCOLOR=\"#ffffff\">\n");
             BIO_puts(io, "<pre>\n");
-/*                      BIO_puts(io,SSLeay_version(SSLEAY_VERSION));*/
+/*                      BIO_puts(io,OpenSSL_version(OPENSSL_VERSION));*/
             BIO_puts(io, "\n");
             for (i = 0; i < local_argc; i++) {
                 const char *myp;
diff --git a/apps/speed.c b/apps/speed.c
index faa3e15..68530b1 100644
--- a/apps/speed.c
+++ b/apps/speed.c
@@ -869,7 +869,7 @@ int speed_main(int argc, char **argv)
 #ifndef OPENSSL_NO_RSA
 # ifndef RSA_NULL
         if (strcmp(*argv, "openssl") == 0) {
-            RSA_set_default_method(RSA_PKCS1_SSLeay());
+            RSA_set_default_method(RSA_PKCS1_OpenSSL());
             continue;
         }
 # endif
@@ -2041,8 +2041,8 @@ int speed_main(int argc, char **argv)
  show_res:
 #endif
     if (!mr) {
-        printf("%s\n", SSLeay_version(SSLEAY_VERSION));
-        printf("%s\n", SSLeay_version(SSLEAY_BUILT_ON));
+        printf("%s\n", OpenSSL_version(OPENSSL_VERSION));
+        printf("%s\n", OpenSSL_version(OPENSSL_BUILT_ON));
         printf("options:");
         printf("%s ", BN_options());
 #ifndef OPENSSL_NO_MD2
@@ -2063,7 +2063,7 @@ int speed_main(int argc, char **argv)
 #ifndef OPENSSL_NO_BF
         printf("%s ", BF_options());
 #endif
-        printf("\n%s\n", SSLeay_version(SSLEAY_CFLAGS));
+        printf("\n%s\n", OpenSSL_version(OPENSSL_CFLAGS));
     }
 
     if (pr_header) {
diff --git a/apps/version.c b/apps/version.c
index 1fa7cfe..073aa93 100644
--- a/apps/version.c
+++ b/apps/version.c
@@ -193,17 +193,17 @@ int version_main(int argc, char **argv)
         version = 1;
 
     if (version) {
-        if (SSLeay() == SSLEAY_VERSION_NUMBER) {
-            printf("%s\n", SSLeay_version(SSLEAY_VERSION));
+        if (OpenSSL_version_num() == OPENSSL_VERSION_NUMBER) {
+            printf("%s\n", OpenSSL_version(OPENSSL_VERSION));
         } else {
             printf("%s (Library: %s)\n",
-                   OPENSSL_VERSION_TEXT, SSLeay_version(SSLEAY_VERSION));
+                   OPENSSL_VERSION_TEXT, OpenSSL_version(OPENSSL_VERSION));
         }
     }
     if (date)
-        printf("%s\n", SSLeay_version(SSLEAY_BUILT_ON));
+        printf("%s\n", OpenSSL_version(OPENSSL_BUILT_ON));
     if (platform)
-        printf("%s\n", SSLeay_version(SSLEAY_PLATFORM));
+        printf("%s\n", OpenSSL_version(OPENSSL_PLATFORM));
     if (options) {
         printf("options:  ");
         printf("%s ", BN_options());
@@ -225,9 +225,9 @@ int version_main(int argc, char **argv)
         printf("\n");
     }
     if (cflags)
-        printf("%s\n", SSLeay_version(SSLEAY_CFLAGS));
+        printf("%s\n", OpenSSL_version(OPENSSL_CFLAGS));
     if (dir)
-        printf("%s\n", SSLeay_version(SSLEAY_DIR));
+        printf("%s\n", OpenSSL_version(OPENSSL_DIR));
     ret = 0;
  end:
     return (ret);
diff --git a/crypto/bn/bn_lcl.h b/crypto/bn/bn_lcl.h
index b9d124a..1a75c10 100644
--- a/crypto/bn/bn_lcl.h
+++ b/crypto/bn/bn_lcl.h
@@ -292,23 +292,11 @@ struct bn_gencb_st {
  * (with draws in between).  Very small exponents are often selected
  * with low Hamming weight, so we use  w = 1  for b <= 23.
  */
-# if 1
-#  define BN_window_bits_for_exponent_size(b) \
+# define BN_window_bits_for_exponent_size(b) \
                 ((b) > 671 ? 6 : \
                  (b) > 239 ? 5 : \
                  (b) >  79 ? 4 : \
                  (b) >  23 ? 3 : 1)
-# else
-/*
- * Old SSLeay/OpenSSL table. Maximum window size was 5, so this table differs
- * for b==1024; but it coincides for other interesting values (b==160,
- * b==512).
- */
-#  define BN_window_bits_for_exponent_size(b) \
-                ((b) > 255 ? 5 : \
-                 (b) > 127 ? 4 : \
-                 (b) >  17 ? 3 : 1)
-# endif
 
 /*
  * BN_mod_exp_mont_conttime is based on the assumption that the L1 data cache
diff --git a/crypto/bn/bn_prime.h b/crypto/bn/bn_prime.h
index 5cf0de1..c2824a8 100644
--- a/crypto/bn/bn_prime.h
+++ b/crypto/bn/bn_prime.h
@@ -63,264 +63,264 @@ typedef unsigned short prime_t;
 # define NUMPRIMES 54
 typedef unsigned char prime_t;
 #endif
-static const prime_t primes[NUMPRIMES] = {
-    2, 3, 5, 7, 11, 13, 17, 19,
-    23, 29, 31, 37, 41, 43, 47, 53,
-    59, 61, 67, 71, 73, 79, 83, 89,
-    97, 101, 103, 107, 109, 113, 127, 131,
-    137, 139, 149, 151, 157, 163, 167, 173,
-    179, 181, 191, 193, 197, 199, 211, 223,
-    227, 229, 233, 239, 241, 251,
+static const prime_t primes[NUMPRIMES]= {
+       2,    3,    5,    7,   11,   13,   17,   19, 
+      23,   29,   31,   37,   41,   43,   47,   53, 
+      59,   61,   67,   71,   73,   79,   83,   89, 
+      97,  101,  103,  107,  109,  113,  127,  131, 
+     137,  139,  149,  151,  157,  163,  167,  173, 
+     179,  181,  191,  193,  197,  199,  211,  223, 
+     227,  229,  233,  239,  241,  251, 
 #ifndef EIGHT_BIT
-    257, 263,
-    269, 271, 277, 281, 283, 293, 307, 311,
-    313, 317, 331, 337, 347, 349, 353, 359,
-    367, 373, 379, 383, 389, 397, 401, 409,
-    419, 421, 431, 433, 439, 443, 449, 457,
-    461, 463, 467, 479, 487, 491, 499, 503,
-    509, 521, 523, 541, 547, 557, 563, 569,
-    571, 577, 587, 593, 599, 601, 607, 613,
-    617, 619, 631, 641, 643, 647, 653, 659,
-    661, 673, 677, 683, 691, 701, 709, 719,
-    727, 733, 739, 743, 751, 757, 761, 769,
-    773, 787, 797, 809, 811, 821, 823, 827,
-    829, 839, 853, 857, 859, 863, 877, 881,
-    883, 887, 907, 911, 919, 929, 937, 941,
-    947, 953, 967, 971, 977, 983, 991, 997,
-    1009, 1013, 1019, 1021, 1031, 1033, 1039, 1049,
-    1051, 1061, 1063, 1069, 1087, 1091, 1093, 1097,
-    1103, 1109, 1117, 1123, 1129, 1151, 1153, 1163,
-    1171, 1181, 1187, 1193, 1201, 1213, 1217, 1223,
-    1229, 1231, 1237, 1249, 1259, 1277, 1279, 1283,
-    1289, 1291, 1297, 1301, 1303, 1307, 1319, 1321,
-    1327, 1361, 1367, 1373, 1381, 1399, 1409, 1423,
-    1427, 1429, 1433, 1439, 1447, 1451, 1453, 1459,
-    1471, 1481, 1483, 1487, 1489, 1493, 1499, 1511,
-    1523, 1531, 1543, 1549, 1553, 1559, 1567, 1571,
-    1579, 1583, 1597, 1601, 1607, 1609, 1613, 1619,
-    1621, 1627, 1637, 1657, 1663, 1667, 1669, 1693,
-    1697, 1699, 1709, 1721, 1723, 1733, 1741, 1747,
-    1753, 1759, 1777, 1783, 1787, 1789, 1801, 1811,
-    1823, 1831, 1847, 1861, 1867, 1871, 1873, 1877,
-    1879, 1889, 1901, 1907, 1913, 1931, 1933, 1949,
-    1951, 1973, 1979, 1987, 1993, 1997, 1999, 2003,
-    2011, 2017, 2027, 2029, 2039, 2053, 2063, 2069,
-    2081, 2083, 2087, 2089, 2099, 2111, 2113, 2129,
-    2131, 2137, 2141, 2143, 2153, 2161, 2179, 2203,
-    2207, 2213, 2221, 2237, 2239, 2243, 2251, 2267,
-    2269, 2273, 2281, 2287, 2293, 2297, 2309, 2311,
-    2333, 2339, 2341, 2347, 2351, 2357, 2371, 2377,
-    2381, 2383, 2389, 2393, 2399, 2411, 2417, 2423,
-    2437, 2441, 2447, 2459, 2467, 2473, 2477, 2503,
-    2521, 2531, 2539, 2543, 2549, 2551, 2557, 2579,
-    2591, 2593, 2609, 2617, 2621, 2633, 2647, 2657,
-    2659, 2663, 2671, 2677, 2683, 2687, 2689, 2693,
-    2699, 2707, 2711, 2713, 2719, 2729, 2731, 2741,
-    2749, 2753, 2767, 2777, 2789, 2791, 2797, 2801,
-    2803, 2819, 2833, 2837, 2843, 2851, 2857, 2861,
-    2879, 2887, 2897, 2903, 2909, 2917, 2927, 2939,
-    2953, 2957, 2963, 2969, 2971, 2999, 3001, 3011,
-    3019, 3023, 3037, 3041, 3049, 3061, 3067, 3079,
-    3083, 3089, 3109, 3119, 3121, 3137, 3163, 3167,
-    3169, 3181, 3187, 3191, 3203, 3209, 3217, 3221,
-    3229, 3251, 3253, 3257, 3259, 3271, 3299, 3301,
-    3307, 3313, 3319, 3323, 3329, 3331, 3343, 3347,
-    3359, 3361, 3371, 3373, 3389, 3391, 3407, 3413,
-    3433, 3449, 3457, 3461, 3463, 3467, 3469, 3491,
-    3499, 3511, 3517, 3527, 3529, 3533, 3539, 3541,
-    3547, 3557, 3559, 3571, 3581, 3583, 3593, 3607,
-    3613, 3617, 3623, 3631, 3637, 3643, 3659, 3671,
-    3673, 3677, 3691, 3697, 3701, 3709, 3719, 3727,
-    3733, 3739, 3761, 3767, 3769, 3779, 3793, 3797,
-    3803, 3821, 3823, 3833, 3847, 3851, 3853, 3863,
-    3877, 3881, 3889, 3907, 3911, 3917, 3919, 3923,
-    3929, 3931, 3943, 3947, 3967, 3989, 4001, 4003,
-    4007, 4013, 4019, 4021, 4027, 4049, 4051, 4057,
-    4073, 4079, 4091, 4093, 4099, 4111, 4127, 4129,
-    4133, 4139, 4153, 4157, 4159, 4177, 4201, 4211,
-    4217, 4219, 4229, 4231, 4241, 4243, 4253, 4259,
-    4261, 4271, 4273, 4283, 4289, 4297, 4327, 4337,
-    4339, 4349, 4357, 4363, 4373, 4391, 4397, 4409,
-    4421, 4423, 4441, 4447, 4451, 4457, 4463, 4481,
-    4483, 4493, 4507, 4513, 4517, 4519, 4523, 4547,
-    4549, 4561, 4567, 4583, 4591, 4597, 4603, 4621,
-    4637, 4639, 4643, 4649, 4651, 4657, 4663, 4673,
-    4679, 4691, 4703, 4721, 4723, 4729, 4733, 4751,
-    4759, 4783, 4787, 4789, 4793, 4799, 4801, 4813,
-    4817, 4831, 4861, 4871, 4877, 4889, 4903, 4909,
-    4919, 4931, 4933, 4937, 4943, 4951, 4957, 4967,
-    4969, 4973, 4987, 4993, 4999, 5003, 5009, 5011,
-    5021, 5023, 5039, 5051, 5059, 5077, 5081, 5087,
-    5099, 5101, 5107, 5113, 5119, 5147, 5153, 5167,
-    5171, 5179, 5189, 5197, 5209, 5227, 5231, 5233,
-    5237, 5261, 5273, 5279, 5281, 5297, 5303, 5309,
-    5323, 5333, 5347, 5351, 5381, 5387, 5393, 5399,
-    5407, 5413, 5417, 5419, 5431, 5437, 5441, 5443,
-    5449, 5471, 5477, 5479, 5483, 5501, 5503, 5507,
-    5519, 5521, 5527, 5531, 5557, 5563, 5569, 5573,
-    5581, 5591, 5623, 5639, 5641, 5647, 5651, 5653,
-    5657, 5659, 5669, 5683, 5689, 5693, 5701, 5711,
-    5717, 5737, 5741, 5743, 5749, 5779, 5783, 5791,
-    5801, 5807, 5813, 5821, 5827, 5839, 5843, 5849,
-    5851, 5857, 5861, 5867, 5869, 5879, 5881, 5897,
-    5903, 5923, 5927, 5939, 5953, 5981, 5987, 6007,
-    6011, 6029, 6037, 6043, 6047, 6053, 6067, 6073,
-    6079, 6089, 6091, 6101, 6113, 6121, 6131, 6133,
-    6143, 6151, 6163, 6173, 6197, 6199, 6203, 6211,
-    6217, 6221, 6229, 6247, 6257, 6263, 6269, 6271,
-    6277, 6287, 6299, 6301, 6311, 6317, 6323, 6329,
-    6337, 6343, 6353, 6359, 6361, 6367, 6373, 6379,
-    6389, 6397, 6421, 6427, 6449, 6451, 6469, 6473,
-    6481, 6491, 6521, 6529, 6547, 6551, 6553, 6563,
-    6569, 6571, 6577, 6581, 6599, 6607, 6619, 6637,
-    6653, 6659, 6661, 6673, 6679, 6689, 6691, 6701,
-    6703, 6709, 6719, 6733, 6737, 6761, 6763, 6779,
-    6781, 6791, 6793, 6803, 6823, 6827, 6829, 6833,
-    6841, 6857, 6863, 6869, 6871, 6883, 6899, 6907,
-    6911, 6917, 6947, 6949, 6959, 6961, 6967, 6971,
-    6977, 6983, 6991, 6997, 7001, 7013, 7019, 7027,
-    7039, 7043, 7057, 7069, 7079, 7103, 7109, 7121,
-    7127, 7129, 7151, 7159, 7177, 7187, 7193, 7207,
-    7211, 7213, 7219, 7229, 7237, 7243, 7247, 7253,
-    7283, 7297, 7307, 7309, 7321, 7331, 7333, 7349,
-    7351, 7369, 7393, 7411, 7417, 7433, 7451, 7457,
-    7459, 7477, 7481, 7487, 7489, 7499, 7507, 7517,
-    7523, 7529, 7537, 7541, 7547, 7549, 7559, 7561,
-    7573, 7577, 7583, 7589, 7591, 7603, 7607, 7621,
-    7639, 7643, 7649, 7669, 7673, 7681, 7687, 7691,
-    7699, 7703, 7717, 7723, 7727, 7741, 7753, 7757,
-    7759, 7789, 7793, 7817, 7823, 7829, 7841, 7853,
-    7867, 7873, 7877, 7879, 7883, 7901, 7907, 7919,
-    7927, 7933, 7937, 7949, 7951, 7963, 7993, 8009,
-    8011, 8017, 8039, 8053, 8059, 8069, 8081, 8087,
-    8089, 8093, 8101, 8111, 8117, 8123, 8147, 8161,
-    8167, 8171, 8179, 8191, 8209, 8219, 8221, 8231,
-    8233, 8237, 8243, 8263, 8269, 8273, 8287, 8291,
-    8293, 8297, 8311, 8317, 8329, 8353, 8363, 8369,
-    8377, 8387, 8389, 8419, 8423, 8429, 8431, 8443,
-    8447, 8461, 8467, 8501, 8513, 8521, 8527, 8537,
-    8539, 8543, 8563, 8573, 8581, 8597, 8599, 8609,
-    8623, 8627, 8629, 8641, 8647, 8663, 8669, 8677,
-    8681, 8689, 8693, 8699, 8707, 8713, 8719, 8731,
-    8737, 8741, 8747, 8753, 8761, 8779, 8783, 8803,
-    8807, 8819, 8821, 8831, 8837, 8839, 8849, 8861,
-    8863, 8867, 8887, 8893, 8923, 8929, 8933, 8941,
-    8951, 8963, 8969, 8971, 8999, 9001, 9007, 9011,
-    9013, 9029, 9041, 9043, 9049, 9059, 9067, 9091,
-    9103, 9109, 9127, 9133, 9137, 9151, 9157, 9161,
-    9173, 9181, 9187, 9199, 9203, 9209, 9221, 9227,
-    9239, 9241, 9257, 9277, 9281, 9283, 9293, 9311,
-    9319, 9323, 9337, 9341, 9343, 9349, 9371, 9377,
-    9391, 9397, 9403, 9413, 9419, 9421, 9431, 9433,
-    9437, 9439, 9461, 9463, 9467, 9473, 9479, 9491,
-    9497, 9511, 9521, 9533, 9539, 9547, 9551, 9587,
-    9601, 9613, 9619, 9623, 9629, 9631, 9643, 9649,
-    9661, 9677, 9679, 9689, 9697, 9719, 9721, 9733,
-    9739, 9743, 9749, 9767, 9769, 9781, 9787, 9791,
-    9803, 9811, 9817, 9829, 9833, 9839, 9851, 9857,
-    9859, 9871, 9883, 9887, 9901, 9907, 9923, 9929,
-    9931, 9941, 9949, 9967, 9973, 10007, 10009, 10037,
-    10039, 10061, 10067, 10069, 10079, 10091, 10093, 10099,
-    10103, 10111, 10133, 10139, 10141, 10151, 10159, 10163,
-    10169, 10177, 10181, 10193, 10211, 10223, 10243, 10247,
-    10253, 10259, 10267, 10271, 10273, 10289, 10301, 10303,
-    10313, 10321, 10331, 10333, 10337, 10343, 10357, 10369,
-    10391, 10399, 10427, 10429, 10433, 10453, 10457, 10459,
-    10463, 10477, 10487, 10499, 10501, 10513, 10529, 10531,
-    10559, 10567, 10589, 10597, 10601, 10607, 10613, 10627,
-    10631, 10639, 10651, 10657, 10663, 10667, 10687, 10691,
-    10709, 10711, 10723, 10729, 10733, 10739, 10753, 10771,
-    10781, 10789, 10799, 10831, 10837, 10847, 10853, 10859,
-    10861, 10867, 10883, 10889, 10891, 10903, 10909, 10937,
-    10939, 10949, 10957, 10973, 10979, 10987, 10993, 11003,
-    11027, 11047, 11057, 11059, 11069, 11071, 11083, 11087,
-    11093, 11113, 11117, 11119, 11131, 11149, 11159, 11161,
-    11171, 11173, 11177, 11197, 11213, 11239, 11243, 11251,
-    11257, 11261, 11273, 11279, 11287, 11299, 11311, 11317,
-    11321, 11329, 11351, 11353, 11369, 11383, 11393, 11399,
-    11411, 11423, 11437, 11443, 11447, 11467, 11471, 11483,
-    11489, 11491, 11497, 11503, 11519, 11527, 11549, 11551,
-    11579, 11587, 11593, 11597, 11617, 11621, 11633, 11657,
-    11677, 11681, 11689, 11699, 11701, 11717, 11719, 11731,
-    11743, 11777, 11779, 11783, 11789, 11801, 11807, 11813,
-    11821, 11827, 11831, 11833, 11839, 11863, 11867, 11887,
-    11897, 11903, 11909, 11923, 11927, 11933, 11939, 11941,
-    11953, 11959, 11969, 11971, 11981, 11987, 12007, 12011,
-    12037, 12041, 12043, 12049, 12071, 12073, 12097, 12101,
-    12107, 12109, 12113, 12119, 12143, 12149, 12157, 12161,
-    12163, 12197, 12203, 12211, 12227, 12239, 12241, 12251,
-    12253, 12263, 12269, 12277, 12281, 12289, 12301, 12323,
-    12329, 12343, 12347, 12373, 12377, 12379, 12391, 12401,
-    12409, 12413, 12421, 12433, 12437, 12451, 12457, 12473,
-    12479, 12487, 12491, 12497, 12503, 12511, 12517, 12527,
-    12539, 12541, 12547, 12553, 12569, 12577, 12583, 12589,
-    12601, 12611, 12613, 12619, 12637, 12641, 12647, 12653,
-    12659, 12671, 12689, 12697, 12703, 12713, 12721, 12739,
-    12743, 12757, 12763, 12781, 12791, 12799, 12809, 12821,
-    12823, 12829, 12841, 12853, 12889, 12893, 12899, 12907,
-    12911, 12917, 12919, 12923, 12941, 12953, 12959, 12967,
-    12973, 12979, 12983, 13001, 13003, 13007, 13009, 13033,
-    13037, 13043, 13049, 13063, 13093, 13099, 13103, 13109,
-    13121, 13127, 13147, 13151, 13159, 13163, 13171, 13177,
-    13183, 13187, 13217, 13219, 13229, 13241, 13249, 13259,
-    13267, 13291, 13297, 13309, 13313, 13327, 13331, 13337,
-    13339, 13367, 13381, 13397, 13399, 13411, 13417, 13421,
-    13441, 13451, 13457, 13463, 13469, 13477, 13487, 13499,
-    13513, 13523, 13537, 13553, 13567, 13577, 13591, 13597,
-    13613, 13619, 13627, 13633, 13649, 13669, 13679, 13681,
-    13687, 13691, 13693, 13697, 13709, 13711, 13721, 13723,
-    13729, 13751, 13757, 13759, 13763, 13781, 13789, 13799,
-    13807, 13829, 13831, 13841, 13859, 13873, 13877, 13879,
-    13883, 13901, 13903, 13907, 13913, 13921, 13931, 13933,
-    13963, 13967, 13997, 13999, 14009, 14011, 14029, 14033,
-    14051, 14057, 14071, 14081, 14083, 14087, 14107, 14143,
-    14149, 14153, 14159, 14173, 14177, 14197, 14207, 14221,
-    14243, 14249, 14251, 14281, 14293, 14303, 14321, 14323,
-    14327, 14341, 14347, 14369, 14387, 14389, 14401, 14407,
-    14411, 14419, 14423, 14431, 14437, 14447, 14449, 14461,
-    14479, 14489, 14503, 14519, 14533, 14537, 14543, 14549,
-    14551, 14557, 14561, 14563, 14591, 14593, 14621, 14627,
-    14629, 14633, 14639, 14653, 14657, 14669, 14683, 14699,
-    14713, 14717, 14723, 14731, 14737, 14741, 14747, 14753,
-    14759, 14767, 14771, 14779, 14783, 14797, 14813, 14821,
-    14827, 14831, 14843, 14851, 14867, 14869, 14879, 14887,
-    14891, 14897, 14923, 14929, 14939, 14947, 14951, 14957,
-    14969, 14983, 15013, 15017, 15031, 15053, 15061, 15073,
-    15077, 15083, 15091, 15101, 15107, 15121, 15131, 15137,
-    15139, 15149, 15161, 15173, 15187, 15193, 15199, 15217,
-    15227, 15233, 15241, 15259, 15263, 15269, 15271, 15277,
-    15287, 15289, 15299, 15307, 15313, 15319, 15329, 15331,
-    15349, 15359, 15361, 15373, 15377, 15383, 15391, 15401,
-    15413, 15427, 15439, 15443, 15451, 15461, 15467, 15473,
-    15493, 15497, 15511, 15527, 15541, 15551, 15559, 15569,
-    15581, 15583, 15601, 15607, 15619, 15629, 15641, 15643,
-    15647, 15649, 15661, 15667, 15671, 15679, 15683, 15727,
-    15731, 15733, 15737, 15739, 15749, 15761, 15767, 15773,
-    15787, 15791, 15797, 15803, 15809, 15817, 15823, 15859,
-    15877, 15881, 15887, 15889, 15901, 15907, 15913, 15919,
-    15923, 15937, 15959, 15971, 15973, 15991, 16001, 16007,
-    16033, 16057, 16061, 16063, 16067, 16069, 16073, 16087,
-    16091, 16097, 16103, 16111, 16127, 16139, 16141, 16183,
-    16187, 16189, 16193, 16217, 16223, 16229, 16231, 16249,
-    16253, 16267, 16273, 16301, 16319, 16333, 16339, 16349,
-    16361, 16363, 16369, 16381, 16411, 16417, 16421, 16427,
-    16433, 16447, 16451, 16453, 16477, 16481, 16487, 16493,
-    16519, 16529, 16547, 16553, 16561, 16567, 16573, 16603,
-    16607, 16619, 16631, 16633, 16649, 16651, 16657, 16661,
-    16673, 16691, 16693, 16699, 16703, 16729, 16741, 16747,
-    16759, 16763, 16787, 16811, 16823, 16829, 16831, 16843,
-    16871, 16879, 16883, 16889, 16901, 16903, 16921, 16927,
-    16931, 16937, 16943, 16963, 16979, 16981, 16987, 16993,
-    17011, 17021, 17027, 17029, 17033, 17041, 17047, 17053,
-    17077, 17093, 17099, 17107, 17117, 17123, 17137, 17159,
-    17167, 17183, 17189, 17191, 17203, 17207, 17209, 17231,
-    17239, 17257, 17291, 17293, 17299, 17317, 17321, 17327,
-    17333, 17341, 17351, 17359, 17377, 17383, 17387, 17389,
-    17393, 17401, 17417, 17419, 17431, 17443, 17449, 17467,
-    17471, 17477, 17483, 17489, 17491, 17497, 17509, 17519,
-    17539, 17551, 17569, 17573, 17579, 17581, 17597, 17599,
-    17609, 17623, 17627, 17657, 17659, 17669, 17681, 17683,
-    17707, 17713, 17729, 17737, 17747, 17749, 17761, 17783,
-    17789, 17791, 17807, 17827, 17837, 17839, 17851, 17863,
+     257,  263, 
+     269,  271,  277,  281,  283,  293,  307,  311, 
+     313,  317,  331,  337,  347,  349,  353,  359, 
+     367,  373,  379,  383,  389,  397,  401,  409, 
+     419,  421,  431,  433,  439,  443,  449,  457, 
+     461,  463,  467,  479,  487,  491,  499,  503, 
+     509,  521,  523,  541,  547,  557,  563,  569, 
+     571,  577,  587,  593,  599,  601,  607,  613, 
+     617,  619,  631,  641,  643,  647,  653,  659, 
+     661,  673,  677,  683,  691,  701,  709,  719, 
+     727,  733,  739,  743,  751,  757,  761,  769, 
+     773,  787,  797,  809,  811,  821,  823,  827, 
+     829,  839,  853,  857,  859,  863,  877,  881, 
+     883,  887,  907,  911,  919,  929,  937,  941, 
+     947,  953,  967,  971,  977,  983,  991,  997, 
+    1009, 1013, 1019, 1021, 1031, 1033, 1039, 1049, 
+    1051, 1061, 1063, 1069, 1087, 1091, 1093, 1097, 
+    1103, 1109, 1117, 1123, 1129, 1151, 1153, 1163, 
+    1171, 1181, 1187, 1193, 1201, 1213, 1217, 1223, 
+    1229, 1231, 1237, 1249, 1259, 1277, 1279, 1283, 
+    1289, 1291, 1297, 1301, 1303, 1307, 1319, 1321, 
+    1327, 1361, 1367, 1373, 1381, 1399, 1409, 1423, 
+    1427, 1429, 1433, 1439, 1447, 1451, 1453, 1459, 
+    1471, 1481, 1483, 1487, 1489, 1493, 1499, 1511, 
+    1523, 1531, 1543, 1549, 1553, 1559, 1567, 1571, 
+    1579, 1583, 1597, 1601, 1607, 1609, 1613, 1619, 
+    1621, 1627, 1637, 1657, 1663, 1667, 1669, 1693, 
+    1697, 1699, 1709, 1721, 1723, 1733, 1741, 1747, 
+    1753, 1759, 1777, 1783, 1787, 1789, 1801, 1811, 
+    1823, 1831, 1847, 1861, 1867, 1871, 1873, 1877, 
+    1879, 1889, 1901, 1907, 1913, 1931, 1933, 1949, 
+    1951, 1973, 1979, 1987, 1993, 1997, 1999, 2003, 
+    2011, 2017, 2027, 2029, 2039, 2053, 2063, 2069, 
+    2081, 2083, 2087, 2089, 2099, 2111, 2113, 2129, 
+    2131, 2137, 2141, 2143, 2153, 2161, 2179, 2203, 
+    2207, 2213, 2221, 2237, 2239, 2243, 2251, 2267, 
+    2269, 2273, 2281, 2287, 2293, 2297, 2309, 2311, 
+    2333, 2339, 2341, 2347, 2351, 2357, 2371, 2377, 
+    2381, 2383, 2389, 2393, 2399, 2411, 2417, 2423, 
+    2437, 2441, 2447, 2459, 2467, 2473, 2477, 2503, 
+    2521, 2531, 2539, 2543, 2549, 2551, 2557, 2579, 
+    2591, 2593, 2609, 2617, 2621, 2633, 2647, 2657, 
+    2659, 2663, 2671, 2677, 2683, 2687, 2689, 2693, 
+    2699, 2707, 2711, 2713, 2719, 2729, 2731, 2741, 
+    2749, 2753, 2767, 2777, 2789, 2791, 2797, 2801, 
+    2803, 2819, 2833, 2837, 2843, 2851, 2857, 2861, 
+    2879, 2887, 2897, 2903, 2909, 2917, 2927, 2939, 
+    2953, 2957, 2963, 2969, 2971, 2999, 3001, 3011, 
+    3019, 3023, 3037, 3041, 3049, 3061, 3067, 3079, 
+    3083, 3089, 3109, 3119, 3121, 3137, 3163, 3167, 
+    3169, 3181, 3187, 3191, 3203, 3209, 3217, 3221, 
+    3229, 3251, 3253, 3257, 3259, 3271, 3299, 3301, 
+    3307, 3313, 3319, 3323, 3329, 3331, 3343, 3347, 
+    3359, 3361, 3371, 3373, 3389, 3391, 3407, 3413, 
+    3433, 3449, 3457, 3461, 3463, 3467, 3469, 3491, 
+    3499, 3511, 3517, 3527, 3529, 3533, 3539, 3541, 
+    3547, 3557, 3559, 3571, 3581, 3583, 3593, 3607, 
+    3613, 3617, 3623, 3631, 3637, 3643, 3659, 3671, 
+    3673, 3677, 3691, 3697, 3701, 3709, 3719, 3727, 
+    3733, 3739, 3761, 3767, 3769, 3779, 3793, 3797, 
+    3803, 3821, 3823, 3833, 3847, 3851, 3853, 3863, 
+    3877, 3881, 3889, 3907, 3911, 3917, 3919, 3923, 
+    3929, 3931, 3943, 3947, 3967, 3989, 4001, 4003, 
+    4007, 4013, 4019, 4021, 4027, 4049, 4051, 4057, 
+    4073, 4079, 4091, 4093, 4099, 4111, 4127, 4129, 
+    4133, 4139, 4153, 4157, 4159, 4177, 4201, 4211, 
+    4217, 4219, 4229, 4231, 4241, 4243, 4253, 4259, 
+    4261, 4271, 4273, 4283, 4289, 4297, 4327, 4337, 
+    4339, 4349, 4357, 4363, 4373, 4391, 4397, 4409, 
+    4421, 4423, 4441, 4447, 4451, 4457, 4463, 4481, 
+    4483, 4493, 4507, 4513, 4517, 4519, 4523, 4547, 
+    4549, 4561, 4567, 4583, 4591, 4597, 4603, 4621, 
+    4637, 4639, 4643, 4649, 4651, 4657, 4663, 4673, 
+    4679, 4691, 4703, 4721, 4723, 4729, 4733, 4751, 
+    4759, 4783, 4787, 4789, 4793, 4799, 4801, 4813, 
+    4817, 4831, 4861, 4871, 4877, 4889, 4903, 4909, 
+    4919, 4931, 4933, 4937, 4943, 4951, 4957, 4967, 
+    4969, 4973, 4987, 4993, 4999, 5003, 5009, 5011, 
+    5021, 5023, 5039, 5051, 5059, 5077, 5081, 5087, 
+    5099, 5101, 5107, 5113, 5119, 5147, 5153, 5167, 
+    5171, 5179, 5189, 5197, 5209, 5227, 5231, 5233, 
+    5237, 5261, 5273, 5279, 5281, 5297, 5303, 5309, 
+    5323, 5333, 5347, 5351, 5381, 5387, 5393, 5399, 
+    5407, 5413, 5417, 5419, 5431, 5437, 5441, 5443, 
+    5449, 5471, 5477, 5479, 5483, 5501, 5503, 5507, 
+    5519, 5521, 5527, 5531, 5557, 5563, 5569, 5573, 
+    5581, 5591, 5623, 5639, 5641, 5647, 5651, 5653, 
+    5657, 5659, 5669, 5683, 5689, 5693, 5701, 5711, 
+    5717, 5737, 5741, 5743, 5749, 5779, 5783, 5791, 
+    5801, 5807, 5813, 5821, 5827, 5839, 5843, 5849, 
+    5851, 5857, 5861, 5867, 5869, 5879, 5881, 5897, 
+    5903, 5923, 5927, 5939, 5953, 5981, 5987, 6007, 
+    6011, 6029, 6037, 6043, 6047, 6053, 6067, 6073, 
+    6079, 6089, 6091, 6101, 6113, 6121, 6131, 6133, 
+    6143, 6151, 6163, 6173, 6197, 6199, 6203, 6211, 
+    6217, 6221, 6229, 6247, 6257, 6263, 6269, 6271, 
+    6277, 6287, 6299, 6301, 6311, 6317, 6323, 6329, 
+    6337, 6343, 6353, 6359, 6361, 6367, 6373, 6379, 
+    6389, 6397, 6421, 6427, 6449, 6451, 6469, 6473, 
+    6481, 6491, 6521, 6529, 6547, 6551, 6553, 6563, 
+    6569, 6571, 6577, 6581, 6599, 6607, 6619, 6637, 
+    6653, 6659, 6661, 6673, 6679, 6689, 6691, 6701, 
+    6703, 6709, 6719, 6733, 6737, 6761, 6763, 6779, 
+    6781, 6791, 6793, 6803, 6823, 6827, 6829, 6833, 
+    6841, 6857, 6863, 6869, 6871, 6883, 6899, 6907, 
+    6911, 6917, 6947, 6949, 6959, 6961, 6967, 6971, 
+    6977, 6983, 6991, 6997, 7001, 7013, 7019, 7027, 
+    7039, 7043, 7057, 7069, 7079, 7103, 7109, 7121, 
+    7127, 7129, 7151, 7159, 7177, 7187, 7193, 7207, 
+    7211, 7213, 7219, 7229, 7237, 7243, 7247, 7253, 
+    7283, 7297, 7307, 7309, 7321, 7331, 7333, 7349, 
+    7351, 7369, 7393, 7411, 7417, 7433, 7451, 7457, 
+    7459, 7477, 7481, 7487, 7489, 7499, 7507, 7517, 
+    7523, 7529, 7537, 7541, 7547, 7549, 7559, 7561, 
+    7573, 7577, 7583, 7589, 7591, 7603, 7607, 7621, 
+    7639, 7643, 7649, 7669, 7673, 7681, 7687, 7691, 
+    7699, 7703, 7717, 7723, 7727, 7741, 7753, 7757, 
+    7759, 7789, 7793, 7817, 7823, 7829, 7841, 7853, 
+    7867, 7873, 7877, 7879, 7883, 7901, 7907, 7919, 
+    7927, 7933, 7937, 7949, 7951, 7963, 7993, 8009, 
+    8011, 8017, 8039, 8053, 8059, 8069, 8081, 8087, 
+    8089, 8093, 8101, 8111, 8117, 8123, 8147, 8161, 
+    8167, 8171, 8179, 8191, 8209, 8219, 8221, 8231, 
+    8233, 8237, 8243, 8263, 8269, 8273, 8287, 8291, 
+    8293, 8297, 8311, 8317, 8329, 8353, 8363, 8369, 
+    8377, 8387, 8389, 8419, 8423, 8429, 8431, 8443, 
+    8447, 8461, 8467, 8501, 8513, 8521, 8527, 8537, 
+    8539, 8543, 8563, 8573, 8581, 8597, 8599, 8609, 
+    8623, 8627, 8629, 8641, 8647, 8663, 8669, 8677, 
+    8681, 8689, 8693, 8699, 8707, 8713, 8719, 8731, 
+    8737, 8741, 8747, 8753, 8761, 8779, 8783, 8803, 
+    8807, 8819, 8821, 8831, 8837, 8839, 8849, 8861, 
+    8863, 8867, 8887, 8893, 8923, 8929, 8933, 8941, 
+    8951, 8963, 8969, 8971, 8999, 9001, 9007, 9011, 
+    9013, 9029, 9041, 9043, 9049, 9059, 9067, 9091, 
+    9103, 9109, 9127, 9133, 9137, 9151, 9157, 9161, 
+    9173, 9181, 9187, 9199, 9203, 9209, 9221, 9227, 
+    9239, 9241, 9257, 9277, 9281, 9283, 9293, 9311, 
+    9319, 9323, 9337, 9341, 9343, 9349, 9371, 9377, 
+    9391, 9397, 9403, 9413, 9419, 9421, 9431, 9433, 
+    9437, 9439, 9461, 9463, 9467, 9473, 9479, 9491, 
+    9497, 9511, 9521, 9533, 9539, 9547, 9551, 9587, 
+    9601, 9613, 9619, 9623, 9629, 9631, 9643, 9649, 
+    9661, 9677, 9679, 9689, 9697, 9719, 9721, 9733, 
+    9739, 9743, 9749, 9767, 9769, 9781, 9787, 9791, 
+    9803, 9811, 9817, 9829, 9833, 9839, 9851, 9857, 
+    9859, 9871, 9883, 9887, 9901, 9907, 9923, 9929, 
+    9931, 9941, 9949, 9967, 9973, 10007, 10009, 10037, 
+    10039, 10061, 10067, 10069, 10079, 10091, 10093, 10099, 
+    10103, 10111, 10133, 10139, 10141, 10151, 10159, 10163, 
+    10169, 10177, 10181, 10193, 10211, 10223, 10243, 10247, 
+    10253, 10259, 10267, 10271, 10273, 10289, 10301, 10303, 
+    10313, 10321, 10331, 10333, 10337, 10343, 10357, 10369, 
+    10391, 10399, 10427, 10429, 10433, 10453, 10457, 10459, 
+    10463, 10477, 10487, 10499, 10501, 10513, 10529, 10531, 
+    10559, 10567, 10589, 10597, 10601, 10607, 10613, 10627, 
+    10631, 10639, 10651, 10657, 10663, 10667, 10687, 10691, 
+    10709, 10711, 10723, 10729, 10733, 10739, 10753, 10771, 
+    10781, 10789, 10799, 10831, 10837, 10847, 10853, 10859, 
+    10861, 10867, 10883, 10889, 10891, 10903, 10909, 10937, 
+    10939, 10949, 10957, 10973, 10979, 10987, 10993, 11003, 
+    11027, 11047, 11057, 11059, 11069, 11071, 11083, 11087, 
+    11093, 11113, 11117, 11119, 11131, 11149, 11159, 11161, 
+    11171, 11173, 11177, 11197, 11213, 11239, 11243, 11251, 
+    11257, 11261, 11273, 11279, 11287, 11299, 11311, 11317, 
+    11321, 11329, 11351, 11353, 11369, 11383, 11393, 11399, 
+    11411, 11423, 11437, 11443, 11447, 11467, 11471, 11483, 
+    11489, 11491, 11497, 11503, 11519, 11527, 11549, 11551, 
+    11579, 11587, 11593, 11597, 11617, 11621, 11633, 11657, 
+    11677, 11681, 11689, 11699, 11701, 11717, 11719, 11731, 
+    11743, 11777, 11779, 11783, 11789, 11801, 11807, 11813, 
+    11821, 11827, 11831, 11833, 11839, 11863, 11867, 11887, 
+    11897, 11903, 11909, 11923, 11927, 11933, 11939, 11941, 
+    11953, 11959, 11969, 11971, 11981, 11987, 12007, 12011, 
+    12037, 12041, 12043, 12049, 12071, 12073, 12097, 12101, 
+    12107, 12109, 12113, 12119, 12143, 12149, 12157, 12161, 
+    12163, 12197, 12203, 12211, 12227, 12239, 12241, 12251, 
+    12253, 12263, 12269, 12277, 12281, 12289, 12301, 12323, 
+    12329, 12343, 12347, 12373, 12377, 12379, 12391, 12401, 
+    12409, 12413, 12421, 12433, 12437, 12451, 12457, 12473, 
+    12479, 12487, 12491, 12497, 12503, 12511, 12517, 12527, 
+    12539, 12541, 12547, 12553, 12569, 12577, 12583, 12589, 
+    12601, 12611, 12613, 12619, 12637, 12641, 12647, 12653, 
+    12659, 12671, 12689, 12697, 12703, 12713, 12721, 12739, 
+    12743, 12757, 12763, 12781, 12791, 12799, 12809, 12821, 
+    12823, 12829, 12841, 12853, 12889, 12893, 12899, 12907, 
+    12911, 12917, 12919, 12923, 12941, 12953, 12959, 12967, 
+    12973, 12979, 12983, 13001, 13003, 13007, 13009, 13033, 
+    13037, 13043, 13049, 13063, 13093, 13099, 13103, 13109, 
+    13121, 13127, 13147, 13151, 13159, 13163, 13171, 13177, 
+    13183, 13187, 13217, 13219, 13229, 13241, 13249, 13259, 
+    13267, 13291, 13297, 13309, 13313, 13327, 13331, 13337, 
+    13339, 13367, 13381, 13397, 13399, 13411, 13417, 13421, 
+    13441, 13451, 13457, 13463, 13469, 13477, 13487, 13499, 
+    13513, 13523, 13537, 13553, 13567, 13577, 13591, 13597, 
+    13613, 13619, 13627, 13633, 13649, 13669, 13679, 13681, 
+    13687, 13691, 13693, 13697, 13709, 13711, 13721, 13723, 
+    13729, 13751, 13757, 13759, 13763, 13781, 13789, 13799, 
+    13807, 13829, 13831, 13841, 13859, 13873, 13877, 13879, 
+    13883, 13901, 13903, 13907, 13913, 13921, 13931, 13933, 
+    13963, 13967, 13997, 13999, 14009, 14011, 14029, 14033, 
+    14051, 14057, 14071, 14081, 14083, 14087, 14107, 14143, 
+    14149, 14153, 14159, 14173, 14177, 14197, 14207, 14221, 
+    14243, 14249, 14251, 14281, 14293, 14303, 14321, 14323, 
+    14327, 14341, 14347, 14369, 14387, 14389, 14401, 14407, 
+    14411, 14419, 14423, 14431, 14437, 14447, 14449, 14461, 
+    14479, 14489, 14503, 14519, 14533, 14537, 14543, 14549, 
+    14551, 14557, 14561, 14563, 14591, 14593, 14621, 14627, 
+    14629, 14633, 14639, 14653, 14657, 14669, 14683, 14699, 
+    14713, 14717, 14723, 14731, 14737, 14741, 14747, 14753, 
+    14759, 14767, 14771, 14779, 14783, 14797, 14813, 14821, 
+    14827, 14831, 14843, 14851, 14867, 14869, 14879, 14887, 
+    14891, 14897, 14923, 14929, 14939, 14947, 14951, 14957, 
+    14969, 14983, 15013, 15017, 15031, 15053, 15061, 15073, 
+    15077, 15083, 15091, 15101, 15107, 15121, 15131, 15137, 
+    15139, 15149, 15161, 15173, 15187, 15193, 15199, 15217, 
+    15227, 15233, 15241, 15259, 15263, 15269, 15271, 15277, 
+    15287, 15289, 15299, 15307, 15313, 15319, 15329, 15331, 
+    15349, 15359, 15361, 15373, 15377, 15383, 15391, 15401, 
+    15413, 15427, 15439, 15443, 15451, 15461, 15467, 15473, 
+    15493, 15497, 15511, 15527, 15541, 15551, 15559, 15569, 
+    15581, 15583, 15601, 15607, 15619, 15629, 15641, 15643, 
+    15647, 15649, 15661, 15667, 15671, 15679, 15683, 15727, 
+    15731, 15733, 15737, 15739, 15749, 15761, 15767, 15773, 
+    15787, 15791, 15797, 15803, 15809, 15817, 15823, 15859, 
+    15877, 15881, 15887, 15889, 15901, 15907, 15913, 15919, 
+    15923, 15937, 15959, 15971, 15973, 15991, 16001, 16007, 
+    16033, 16057, 16061, 16063, 16067, 16069, 16073, 16087, 
+    16091, 16097, 16103, 16111, 16127, 16139, 16141, 16183, 
+    16187, 16189, 16193, 16217, 16223, 16229, 16231, 16249, 
+    16253, 16267, 16273, 16301, 16319, 16333, 16339, 16349, 
+    16361, 16363, 16369, 16381, 16411, 16417, 16421, 16427, 
+    16433, 16447, 16451, 16453, 16477, 16481, 16487, 16493, 
+    16519, 16529, 16547, 16553, 16561, 16567, 16573, 16603, 
+    16607, 16619, 16631, 16633, 16649, 16651, 16657, 16661, 
+    16673, 16691, 16693, 16699, 16703, 16729, 16741, 16747, 
+    16759, 16763, 16787, 16811, 16823, 16829, 16831, 16843, 
+    16871, 16879, 16883, 16889, 16901, 16903, 16921, 16927, 
+    16931, 16937, 16943, 16963, 16979, 16981, 16987, 16993, 
+    17011, 17021, 17027, 17029, 17033, 17041, 17047, 17053, 
+    17077, 17093, 17099, 17107, 17117, 17123, 17137, 17159, 
+    17167, 17183, 17189, 17191, 17203, 17207, 17209, 17231, 
+    17239, 17257, 17291, 17293, 17299, 17317, 17321, 17327, 
+    17333, 17341, 17351, 17359, 17377, 17383, 17387, 17389, 
+    17393, 17401, 17417, 17419, 17431, 17443, 17449, 17467, 
+    17471, 17477, 17483, 17489, 17491, 17497, 17509, 17519, 
+    17539, 17551, 17569, 17573, 17579, 17581, 17597, 17599, 
+    17609, 17623, 17627, 17657, 17659, 17669, 17681, 17683, 
+    17707, 17713, 17729, 17737, 17747, 17749, 17761, 17783, 
+    17789, 17791, 17807, 17827, 17837, 17839, 17851, 17863, 
 #endif
 };
diff --git a/crypto/bn/bn_prime.pl b/crypto/bn/bn_prime.pl
index 3fafb6f..4e4426a 100644
--- a/crypto/bn/bn_prime.pl
+++ b/crypto/bn/bn_prime.pl
@@ -18,17 +18,6 @@ loop: while ($#primes < $num-1)
 	push(@primes,$p);
 	}
 
-# print <<"EOF";
-# /* Auto generated by bn_prime.pl */
-# /* Copyright (C) 1995-1997 Eric Young (eay\@mincom.oz.au).
-#  * All rights reserved.
-#  * Copyright remains Eric Young's, and as such any Copyright notices in
-#  * the code are not to be removed.
-#  * See the COPYRIGHT file in the SSLeay distribution for more details.
-#  */
-# 
-# EOF
-
 print <<\EOF;
 /* Auto generated by bn_prime.pl */
 /* Copyright (C) 1995-1998 Eric Young (eay at cryptsoft.com)
@@ -37,21 +26,21 @@ print <<\EOF;
  * This package is an SSL implementation written
  * by Eric Young (eay at cryptsoft.com).
  * The implementation was written so as to conform with Netscapes SSL.
- * 
+ *
  * This library is free for commercial and non-commercial use as long as
  * the following conditions are aheared to.  The following conditions
  * apply to all code found in this distribution, be it the RC4, RSA,
  * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
  * included with this distribution is covered by the same copyright terms
  * except that the holder is Tim Hudson (tjh at cryptsoft.com).
- * 
+ *
  * Copyright remains Eric Young's, and as such any Copyright notices in
  * the code are not to be removed.
  * If this package is used in a product, Eric Young should be given attribution
  * as the author of the parts of the library used.
  * This can be in the form of a textual message at program startup or
  * in documentation (online or textual) provided with the package.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -66,10 +55,10 @@ print <<\EOF;
  *     Eric Young (eay at cryptsoft.com)"
  *    The word 'cryptographic' can be left out if the rouines from the library
  *    being used are not cryptographic related :-).
- * 4. If you include any Windows specific code (or a derivative thereof) from 
+ * 4. If you include any Windows specific code (or a derivative thereof) from
  *    the apps directory (application code) you must include an acknowledgement:
  *    "This product includes software written by Tim Hudson (tjh at cryptsoft.com)"
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -81,7 +70,7 @@ print <<\EOF;
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
- * 
+ *
  * The licence and distribution terms for any publically available version or
  * derivative of this code cannot be changed.  i.e. this code cannot simply be
  * copied and put under another distribution licence
@@ -100,20 +89,18 @@ for ($i=0; $i <= $#primes; $i++)
 	}
 
 printf "#ifndef EIGHT_BIT\n";
-printf "#define NUMPRIMES %d\n",$num;
+printf "# define NUMPRIMES %d\n",$num;
 printf "typedef unsigned short prime_t;\n";
 printf "#else\n";
-printf "#define NUMPRIMES %d\n",$eight;
+printf "# define NUMPRIMES %d\n",$eight;
 printf "typedef unsigned char prime_t;\n";
 printf "#endif\n";
-print "static const prime_t primes[NUMPRIMES]=\n\t{\n\t";
+print "static const prime_t primes[NUMPRIMES]= {\n    ";
 $init=0;
 for ($i=0; $i <= $#primes; $i++)
 	{
-	printf "\n#ifndef EIGHT_BIT\n\t" if ($primes[$i] > 256) && !($init++);
-	printf("\n\t") if (($i%8) == 0) && ($i != 0);
-	printf("%4d,",$primes[$i]);
+	printf "\n#ifndef EIGHT_BIT\n    " if ($primes[$i] > 256) && !($init++);
+	printf "\n    " if (($i%8) == 0) && ($i != 0);
+	printf "%4d, ", $primes[$i];
 	}
-print "\n#endif\n\t};\n";
-
-
+print "\n#endif\n};\n";
diff --git a/crypto/cversion.c b/crypto/cversion.c
index 6111b65..aa479a9 100644
--- a/crypto/cversion.c
+++ b/crypto/cversion.c
@@ -62,11 +62,16 @@
 # include "buildinf.h"
 #endif
 
-const char *SSLeay_version(int t)
+unsigned long OpenSSL_version_num()
 {
-    if (t == SSLEAY_VERSION)
+    return OPENSSL_VERSION_NUMBER;
+}
+
+const char *OpenSSL_version(int t)
+{
+    if (t == OPENSSL_VERSION)
         return OPENSSL_VERSION_TEXT;
-    if (t == SSLEAY_BUILT_ON) {
+    if (t == OPENSSL_BUILT_ON) {
 #ifdef DATE
 # ifdef OPENSSL_USE_BUILD_DATE
         return (DATE);
@@ -77,21 +82,21 @@ const char *SSLeay_version(int t)
         return ("built on: date not available");
 #endif
     }
-    if (t == SSLEAY_CFLAGS) {
+    if (t == OPENSSL_CFLAGS) {
 #ifdef CFLAGS
         return (CFLAGS);
 #else
         return ("compiler: information not available");
 #endif
     }
-    if (t == SSLEAY_PLATFORM) {
+    if (t == OPENSSL_PLATFORM) {
 #ifdef PLATFORM
         return (PLATFORM);
 #else
         return ("platform: information not available");
 #endif
     }
-    if (t == SSLEAY_DIR) {
+    if (t == OPENSSL_DIR) {
 #ifdef OPENSSLDIR
         return "OPENSSLDIR: \"" OPENSSLDIR "\"";
 #else
@@ -100,8 +105,3 @@ const char *SSLeay_version(int t)
     }
     return ("not available");
 }
-
-unsigned long SSLeay(void)
-{
-    return (SSLEAY_VERSION_NUMBER);
-}
diff --git a/crypto/des/Makefile b/crypto/des/Makefile
index 56c41f1..1233fad 100644
--- a/crypto/des/Makefile
+++ b/crypto/des/Makefile
@@ -114,7 +114,7 @@ ecb_enc.o: ../../include/openssl/des.h ../../include/openssl/e_os2.h
 ecb_enc.o: ../../include/openssl/opensslconf.h ../../include/openssl/opensslv.h
 ecb_enc.o: ../../include/openssl/ossl_typ.h ../../include/openssl/safestack.h
 ecb_enc.o: ../../include/openssl/stack.h ../../include/openssl/symhacks.h
-ecb_enc.o: des_locl.h des_ver.h ecb_enc.c
+ecb_enc.o: des_locl.h ecb_enc.c
 enc_read.o: ../../e_os.h ../../include/openssl/bio.h
 enc_read.o: ../../include/openssl/buffer.h ../../include/openssl/crypto.h
 enc_read.o: ../../include/openssl/des.h ../../include/openssl/e_os2.h
@@ -161,8 +161,7 @@ read2pwd.o: ../../include/openssl/safestack.h ../../include/openssl/stack.h
 read2pwd.o: ../../include/openssl/symhacks.h ../../include/openssl/ui.h
 read2pwd.o: read2pwd.c
 rpc_enc.o: ../../include/openssl/des.h ../../include/openssl/e_os2.h
-rpc_enc.o: ../../include/openssl/opensslconf.h des_locl.h des_ver.h rpc_des.h
-rpc_enc.o: rpc_enc.c
+rpc_enc.o: ../../include/openssl/opensslconf.h des_locl.h rpc_des.h rpc_enc.c
 set_key.o: ../../include/openssl/crypto.h ../../include/openssl/des.h
 set_key.o: ../../include/openssl/e_os2.h ../../include/openssl/opensslconf.h
 set_key.o: ../../include/openssl/opensslv.h ../../include/openssl/ossl_typ.h
diff --git a/crypto/des/des_ver.h b/crypto/des/des_ver.h
deleted file mode 100644
index 276de2b..0000000
--- a/crypto/des/des_ver.h
+++ /dev/null
@@ -1,73 +0,0 @@
-/* crypto/des/des_ver.h */
-/* Copyright (C) 1995-1998 Eric Young (eay at cryptsoft.com)
- * All rights reserved.
- *
- * This package is an SSL implementation written
- * by Eric Young (eay at cryptsoft.com).
- * The implementation was written so as to conform with Netscapes SSL.
- *
- * This library is free for commercial and non-commercial use as long as
- * the following conditions are aheared to.  The following conditions
- * apply to all code found in this distribution, be it the RC4, RSA,
- * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
- * included with this distribution is covered by the same copyright terms
- * except that the holder is Tim Hudson (tjh at cryptsoft.com).
- *
- * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.
- * If this package is used in a product, Eric Young should be given attribution
- * as the author of the parts of the library used.
- * This can be in the form of a textual message at program startup or
- * in documentation (online or textual) provided with the package.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *    "This product includes cryptographic software written by
- *     Eric Young (eay at cryptsoft.com)"
- *    The word 'cryptographic' can be left out if the rouines from the library
- *    being used are not cryptographic related :-).
- * 4. If you include any Windows specific code (or a derivative thereof) from
- *    the apps directory (application code) you must include an acknowledgement:
- *    "This product includes software written by Tim Hudson (tjh at cryptsoft.com)"
- *
- * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- *
- * The licence and distribution terms for any publically available version or
- * derivative of this code cannot be changed.  i.e. this code cannot simply be
- * copied and put under another distribution licence
- * [including the GNU Public Licence.]
- */
-
-#include <openssl/e_os2.h>
-
-#ifdef OPENSSL_BUILD_SHLIBCRYPTO
-# undef OPENSSL_EXTERN
-# define OPENSSL_EXTERN OPENSSL_EXPORT
-#endif
-
-/* The following macros make sure the names are different from libdes names */
-#define DES_version OSSL_DES_version
-#define libdes_version OSSL_libdes_version
-
-/* SSLeay version string */
-OPENSSL_EXTERN const char OSSL_DES_version[];
-/* old libdes version string */
-OPENSSL_EXTERN const char OSSL_libdes_version[];
diff --git a/crypto/des/ecb_enc.c b/crypto/des/ecb_enc.c
index d638a49..4f104ea 100644
--- a/crypto/des/ecb_enc.c
+++ b/crypto/des/ecb_enc.c
@@ -57,7 +57,6 @@
  */
 
 #include "des_locl.h"
-#include "des_ver.h"
 #include <openssl/opensslv.h>
 #include <openssl/bio.h>
 
diff --git a/crypto/des/rpc_enc.c b/crypto/des/rpc_enc.c
index a5cd7dd..2245bca 100644
--- a/crypto/des/rpc_enc.c
+++ b/crypto/des/rpc_enc.c
@@ -58,7 +58,6 @@
 
 #include "rpc_des.h"
 #include "des_locl.h"
-#include "des_ver.h"
 
 int _des_crypt(char *buf, int len, struct desparams *desp);
 int _des_crypt(char *buf, int len, struct desparams *desp)
diff --git a/crypto/engine/eng_cryptodev.c b/crypto/engine/eng_cryptodev.c
index c660bb3..d058dba 100644
--- a/crypto/engine/eng_cryptodev.c
+++ b/crypto/engine/eng_cryptodev.c
@@ -1129,12 +1129,12 @@ cryptodev_bn_mod_exp(BIGNUM *r, const BIGNUM *a, const BIGNUM *p,
     kop.crk_iparams = 3;
 
     if (cryptodev_asym(&kop, BN_num_bytes(m), r, 0, NULL)) {
-        const RSA_METHOD *meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *meth = RSA_PKCS1_OpenSSL();
         printf("OCF asym process failed, Running in software\n");
         ret = meth->bn_mod_exp(r, a, p, m, ctx, in_mont);
 
     } else if (ECANCELED == kop.crk_status) {
-        const RSA_METHOD *meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *meth = RSA_PKCS1_OpenSSL();
         printf("OCF hardware operation cancelled. Running in Software\n");
         ret = meth->bn_mod_exp(r, a, p, m, ctx, in_mont);
     }
@@ -1185,12 +1185,12 @@ cryptodev_rsa_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
     kop.crk_iparams = 6;
 
     if (cryptodev_asym(&kop, BN_num_bytes(rsa->n), r0, 0, NULL)) {
-        const RSA_METHOD *meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *meth = RSA_PKCS1_OpenSSL();
         printf("OCF asym process failed, running in Software\n");
         ret = (*meth->rsa_mod_exp) (r0, I, rsa, ctx);
 
     } else if (ECANCELED == kop.crk_status) {
-        const RSA_METHOD *meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *meth = RSA_PKCS1_OpenSSL();
         printf("OCF hardware operation cancelled. Running in Software\n");
         ret = (*meth->rsa_mod_exp) (r0, I, rsa, ctx);
     }
@@ -1477,7 +1477,7 @@ void ENGINE_load_cryptodev(void)
     }
 
     if (ENGINE_set_RSA(engine, &cryptodev_rsa)) {
-        const RSA_METHOD *rsa_meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *rsa_meth = RSA_PKCS1_OpenSSL();
 
         cryptodev_rsa.bn_mod_exp = rsa_meth->bn_mod_exp;
         cryptodev_rsa.rsa_mod_exp = rsa_meth->rsa_mod_exp;
diff --git a/crypto/engine/eng_openssl.c b/crypto/engine/eng_openssl.c
index 095b5a0..244a609 100644
--- a/crypto/engine/eng_openssl.c
+++ b/crypto/engine/eng_openssl.c
@@ -158,7 +158,7 @@ static int bind_helper(ENGINE *e)
 # ifndef OPENSSL_NO_DH
         || !ENGINE_set_DH(e, DH_get_default_method())
 # endif
-        || !ENGINE_set_RAND(e, RAND_SSLeay())
+        || !ENGINE_set_RAND(e, RAND_OpenSSL())
 # ifdef TEST_ENG_OPENSSL_RC4
         || !ENGINE_set_ciphers(e, openssl_ciphers)
 # endif
diff --git a/crypto/lhash/lh_stats.c b/crypto/lhash/lh_stats.c
index 09e1bff..b7d9524 100644
--- a/crypto/lhash/lh_stats.c
+++ b/crypto/lhash/lh_stats.c
@@ -60,7 +60,7 @@
 #include <string.h>
 #include <stdlib.h>
 /*
- * If you wish to build this outside of SSLeay, remove the following lines
+ * If you wish to build this outside of OpenSSL, remove the following lines
  * and things should work as expected
  */
 #include "internal/cryptlib.h"
diff --git a/crypto/lock.c b/crypto/lock.c
index 12e4323..d24527a 100644
--- a/crypto/lock.c
+++ b/crypto/lock.c
@@ -118,7 +118,7 @@
 #include <openssl/safestack.h>
 
 #if defined(OPENSSL_SYS_WIN32)
-static double SSLeay_MSVC5_hack = 0.0; /* and for VC1.5 */
+static double OpenSSL_MSVC5_hack = 0.0; /* and for VC1.5 */
 #endif
 
 DECLARE_STACK_OF(CRYPTO_dynlock)
@@ -207,7 +207,7 @@ int CRYPTO_get_new_lockid(char *name)
      * using /MT. Without this, the application cannot use any floating point
      * printf's. It also seems to be needed for Visual C 1.5 (win16)
      */
-    SSLeay_MSVC5_hack = (double)name[0] * (double)name[1];
+    OpenSSL_MSVC5_hack = (double)name[0] * (double)name[1];
 #endif
 
     if ((app_locks == NULL)
diff --git a/crypto/rand/rand_err.c b/crypto/rand/rand_err.c
index 6ab904d..c22677e 100644
--- a/crypto/rand/rand_err.c
+++ b/crypto/rand/rand_err.c
@@ -1,6 +1,6 @@
 /* crypto/rand/rand_err.c */
 /* ====================================================================
- * Copyright (c) 1999-2010 The OpenSSL Project.  All rights reserved.
+ * Copyright (c) 1999-2015 The OpenSSL Project.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -75,8 +75,8 @@ static ERR_STRING_DATA RAND_str_functs[] = {
     {ERR_FUNC(RAND_F_FIPS_SET_PRNG_SEED), "FIPS_SET_PRNG_SEED"},
     {ERR_FUNC(RAND_F_FIPS_SET_TEST_MODE), "FIPS_SET_TEST_MODE"},
     {ERR_FUNC(RAND_F_FIPS_X931_SET_DT), "FIPS_x931_set_dt"},
+    {ERR_FUNC(RAND_F_RAND_BYTES), "RAND_bytes"},
     {ERR_FUNC(RAND_F_RAND_GET_RAND_METHOD), "RAND_get_rand_method"},
-    {ERR_FUNC(RAND_F_SSLEAY_RAND_BYTES), "SSLEAY_RAND_BYTES"},
     {0, NULL}
 };
 
diff --git a/crypto/rand/rand_lib.c b/crypto/rand/rand_lib.c
index 102ed05..55c90cc 100644
--- a/crypto/rand/rand_lib.c
+++ b/crypto/rand/rand_lib.c
@@ -104,7 +104,7 @@ const RAND_METHOD *RAND_get_rand_method(void)
             funct_ref = e;
         else
 #endif
-            default_RAND_meth = RAND_SSLeay();
+            default_RAND_meth = RAND_OpenSSL();
     }
     return default_RAND_meth;
 }
@@ -197,7 +197,7 @@ static size_t drbg_get_entropy(DRBG_CTX *ctx, unsigned char **pout,
     *pout = OPENSSL_malloc(min_len);
     if (!*pout)
         return 0;
-    if (RAND_SSLeay()->bytes(*pout, min_len) <= 0) {
+    if (RAND_OpenSSL()->bytes(*pout, min_len) <= 0) {
         OPENSSL_free(*pout);
         *pout = NULL;
         return 0;
@@ -234,12 +234,12 @@ static size_t drbg_get_adin(DRBG_CTX *ctx, unsigned char **pout)
 static int drbg_rand_add(DRBG_CTX *ctx, const void *in, int inlen,
                          double entropy)
 {
-    return RAND_SSLeay()->add(in, inlen, entropy);
+    return RAND_OpenSSL()->add(in, inlen, entropy);
 }
 
 static int drbg_rand_seed(DRBG_CTX *ctx, const void *in, int inlen)
 {
-    return RAND_SSLeay()->seed(in, inlen);
+    return RAND_OpenSSL()->seed(in, inlen);
 }
 
 int RAND_init_fips(void)
diff --git a/crypto/rsa/rsa_eay.c b/crypto/rsa/rsa_eay.c
index 837e915..a41964d 100644
--- a/crypto/rsa/rsa_eay.c
+++ b/crypto/rsa/rsa_eay.c
@@ -146,7 +146,7 @@ static RSA_METHOD rsa_pkcs1_eay_meth = {
     NULL                        /* rsa_keygen */
 };
 
-const RSA_METHOD *RSA_PKCS1_SSLeay(void)
+const RSA_METHOD *RSA_PKCS1_OpenSSL(void)
 {
     return (&rsa_pkcs1_eay_meth);
 }
diff --git a/crypto/rsa/rsa_lib.c b/crypto/rsa/rsa_lib.c
index c64dad4..594722b 100644
--- a/crypto/rsa/rsa_lib.c
+++ b/crypto/rsa/rsa_lib.c
@@ -87,7 +87,7 @@ const RSA_METHOD *RSA_get_default_method(void)
 #ifdef RSA_NULL
         default_RSA_meth = RSA_null_method();
 #else
-        default_RSA_meth = RSA_PKCS1_SSLeay();
+        default_RSA_meth = RSA_PKCS1_OpenSSL();
 #endif
     }
 
diff --git a/demos/easy_tls/easy-tls.c b/demos/easy_tls/easy-tls.c
index 5b65780..e42d28a 100644
--- a/demos/easy_tls/easy-tls.c
+++ b/demos/easy_tls/easy-tls.c
@@ -418,7 +418,7 @@ static int tls_init(void *apparg)
         return 0;
 
     SSL_load_error_strings();
-    if (!SSL_library_init() /* aka SSLeay_add_ssl_algorithms() */ ) {
+    if (!SSL_library_init()) {
         tls_errprintf(1, apparg, "SSL_library_init failed.\n");
         return -1;
     }
diff --git a/demos/pkcs12/pkwrite.c b/demos/pkcs12/pkwrite.c
index 34e82dd..753fbfe 100644
--- a/demos/pkcs12/pkwrite.c
+++ b/demos/pkcs12/pkwrite.c
@@ -18,7 +18,7 @@ int main(int argc, char **argv)
         fprintf(stderr, "Usage: pkwrite infile password name p12file\n");
         exit(1);
     }
-    SSLeay_add_all_algorithms();
+    OpenSSL_add_all_algorithms();
     ERR_load_crypto_strings();
     if ((fp = fopen(argv[1], "r")) == NULL) {
         fprintf(stderr, "Error opening file %s\n", argv[1]);
diff --git a/demos/sign/sign.c b/demos/sign/sign.c
index 22f53fb..f6aab25 100644
--- a/demos/sign/sign.c
+++ b/demos/sign/sign.c
@@ -57,7 +57,7 @@
  */
 
 /*
- * sign-it.cpp - Simple test app using SSLeay envelopes to sign data
+ * sign-it.cpp - Simple test app using EVP envelopes to sign data
  * 29.9.1996, Sampo Kellomaki <sampo at iki.fi>
  */
 
diff --git a/demos/ssl/cli.cpp b/demos/ssl/cli.cpp
index 3459f0f..fcc4d9d 100644
--- a/demos/ssl/cli.cpp
+++ b/demos/ssl/cli.cpp
@@ -1,7 +1,7 @@
 /* cli.cpp  -  Minimal ssleay client for Unix
    30.9.1996, Sampo Kellomaki <sampo at iki.fi> */
 
-/* mangled to work with SSLeay-0.9.0b and OpenSSL 0.9.2b
+/* mangled to work with OpenSSL 0.9.2b
    Simplified to be even more minimal
    12/98 - 4/99 Wade Scholine <wades at mail.cybg.com> */
 
@@ -37,7 +37,7 @@ void main ()
   char     buf [4096];
   SSL_METHOD *meth;
 
-  SSLeay_add_ssl_algorithms();
+  OpenSSL_add_ssl_algorithms();
   meth = TLS_client_method();
   SSL_load_error_strings();
   ctx = SSL_CTX_new (meth);                        CHK_NULL(ctx);
diff --git a/demos/ssl/inetdsrv.cpp b/demos/ssl/inetdsrv.cpp
index efd70d2..7434030 100644
--- a/demos/ssl/inetdsrv.cpp
+++ b/demos/ssl/inetdsrv.cpp
@@ -7,7 +7,7 @@
 #include <stdio.h>
 #include <errno.h>
 
-#include "rsa.h"       /* SSLeay stuff */
+#include "rsa.h"
 #include <openssl/crypto.h>
 #include <openssl/x509.h>
 #include <openssl/pem.h>
diff --git a/demos/ssl/serv.cpp b/demos/ssl/serv.cpp
index 9cb77f8..43ff88e 100644
--- a/demos/ssl/serv.cpp
+++ b/demos/ssl/serv.cpp
@@ -2,7 +2,7 @@
    30.9.1996, Sampo Kellomaki <sampo at iki.fi> */
 
 
-/* mangled to work with SSLeay-0.9.0b and OpenSSL 0.9.2b
+/* mangled to work with OpenSSL 0.9.2b
    Simplified to be even more minimal
    12/98 - 4/99 Wade Scholine <wades at mail.cybg.com> */
 
@@ -17,7 +17,7 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 
-#include <openssl/rsa.h>       /* SSLeay stuff */
+#include <openssl/rsa.h>
 #include <openssl/crypto.h>
 #include <openssl/x509.h>
 #include <openssl/pem.h>
@@ -54,7 +54,7 @@ void main ()
   /* SSL preliminaries. We keep the certificate and key with the context. */
 
   SSL_load_error_strings();
-  SSLeay_add_ssl_algorithms();
+  OpenSSL_add_ssl_algorithms();
   meth = TLS_server_method();
   ctx = SSL_CTX_new (meth);
   if (!ctx) {
diff --git a/doc/apps/dhparam.pod b/doc/apps/dhparam.pod
index b0a9802..5919935 100644
--- a/doc/apps/dhparam.pod
+++ b/doc/apps/dhparam.pod
@@ -117,7 +117,7 @@ for all available algorithms.
 =head1 WARNINGS
 
 The program B<dhparam> combines the functionality of the programs B<dh> and
-B<gendh> in previous versions of OpenSSL and SSLeay. The B<dh> and B<gendh>
+B<gendh> in previous versions of OpenSSL. The B<dh> and B<gendh>
 programs are retained for now but may have different purposes in future 
 versions of OpenSSL.
 
diff --git a/doc/apps/enc.pod b/doc/apps/enc.pod
index 26e678c..8f7e1cb 100644
--- a/doc/apps/enc.pod
+++ b/doc/apps/enc.pod
@@ -62,8 +62,7 @@ use a salt in the key derivation routines. This is the default.
 =item B<-nosalt>
 
 don't use a salt in the key derivation routines. This option B<SHOULD NOT> be
-used except for test purposes or compatibility with ancient versions of OpenSSL
-and SSLeay.
+used except for test purposes or compatibility with ancient versions of OpenSSL.
 
 =item B<-e>
 
@@ -181,7 +180,7 @@ A password will be prompted for to derive the key and IV if necessary.
 
 The B<-salt> option should B<ALWAYS> be used if the key is being derived
 from a password unless you want compatibility with previous versions of
-OpenSSL and SSLeay.
+OpenSSL.
 
 Without the B<-salt> option it is possible to perform efficient dictionary
 attacks on the password and to attack stream cipher encrypted data. The reason
diff --git a/doc/apps/req.pod b/doc/apps/req.pod
index ec19192..880061e 100644
--- a/doc/apps/req.pod
+++ b/doc/apps/req.pod
@@ -621,8 +621,7 @@ for more information.
 
 The variable B<OPENSSL_CONF> if defined allows an alternative configuration
 file location to be specified, it will be overridden by the B<-config> command
-line switch if it is present. For compatibility reasons the B<SSLEAY_CONF>
-environment variable serves the same purpose but its use is discouraged.
+line switch if it is present.
 
 =head1 BUGS
 
diff --git a/doc/apps/verify.pod b/doc/apps/verify.pod
index c935269..74477e5 100644
--- a/doc/apps/verify.pod
+++ b/doc/apps/verify.pod
@@ -307,7 +307,7 @@ the B<CERTIFICATE EXTENSIONS> section of the B<x509> utility.
 
 The third operation is to check the trust settings on the root CA. The root
 CA should be trusted for the supplied purpose. For compatibility with previous
-versions of SSLeay and OpenSSL a certificate with no trust settings is considered
+versions of OpenSSL, a certificate with no trust settings is considered
 to be valid for all purposes. 
 
 The final operation is to check the validity of the certificate chain. The validity
diff --git a/doc/crypto/OPENSSL_VERSION_NUMBER.pod b/doc/crypto/OPENSSL_VERSION_NUMBER.pod
index c8fed0f..fc16536 100644
--- a/doc/crypto/OPENSSL_VERSION_NUMBER.pod
+++ b/doc/crypto/OPENSSL_VERSION_NUMBER.pod
@@ -2,7 +2,8 @@
 
 =head1 NAME
 
-OPENSSL_VERSION_NUMBER, OpenSSL_version - get OpenSSL version number
+OPENSSL_VERSION_NUMBER, OpenSSL_version,
+OpenSSL_version_num - get OpenSSL version number
 
 =head1 SYNOPSIS
 
@@ -10,6 +11,8 @@ OPENSSL_VERSION_NUMBER, OpenSSL_version - get OpenSSL version number
  #define OPENSSL_VERSION_NUMBER 0xnnnnnnnnnL
 
  #include <openssl/crypto.h>
+
+ unsigned long OpenSSL_version_num();
  const char *OpenSSL_version(int t);
 
 =head1 DESCRIPTION
@@ -42,8 +45,7 @@ Version 0.9.5a had an interim interpretation that is like the current one,
 except the patch level got the highest bit set, to keep continuity.  The
 number was therefore 0x0090581f.
 
-
-For backward compatibility, OPENSSL_VERSION_NUMBER is also defined.
+OpenSSL_version_num() returns the version number.
 
 OpenSSL_version() returns different strings depending on B<t>:
 
diff --git a/doc/crypto/RAND_set_rand_method.pod b/doc/crypto/RAND_set_rand_method.pod
index fe7f441..533d577 100644
--- a/doc/crypto/RAND_set_rand_method.pod
+++ b/doc/crypto/RAND_set_rand_method.pod
@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-RAND_set_rand_method, RAND_get_rand_method, RAND_SSLeay - select RAND method
+RAND_set_rand_method, RAND_get_rand_method, RAND_OpenSSL - select RAND method
 
 =head1 SYNOPSIS
 
@@ -12,7 +12,7 @@ RAND_set_rand_method, RAND_get_rand_method, RAND_SSLeay - select RAND method
 
  const RAND_METHOD *RAND_get_rand_method(void);
 
- RAND_METHOD *RAND_SSLeay(void);
+ RAND_METHOD *RAND_OpenSSL(void);
 
 =head1 DESCRIPTION
 
@@ -23,7 +23,7 @@ information about how these RAND API functions are affected by the use of
 B<ENGINE> API calls.
 
 Initially, the default RAND_METHOD is the OpenSSL internal implementation, as
-returned by RAND_SSLeay().
+returned by RAND_OpenSSL().
 
 RAND_set_default_method() makes B<meth> the method for PRNG use. B<NB>: This is
 true only whilst no ENGINE has been set as a default for RAND, so this function
@@ -53,7 +53,7 @@ Each component may be NULL if the function is not implemented.
 =head1 RETURN VALUES
 
 RAND_set_rand_method() returns no value. RAND_get_rand_method() and
-RAND_SSLeay() return pointers to the respective methods.
+RAND_OpenSSL() return pointers to the respective methods.
 
 =head1 NOTES
 
diff --git a/doc/crypto/SSLeay_version.pod b/doc/crypto/SSLeay_version.pod
deleted file mode 100644
index 4862cd4..0000000
--- a/doc/crypto/SSLeay_version.pod
+++ /dev/null
@@ -1,70 +0,0 @@
-=pod
-
-=head1 NAME
-
-SSLeay_version - retrieve version/build information about OpenSSL library
-
-=head1 SYNOPSIS
-
- #include <openssl/crypto.h>
-
- const char *SSLeay_version(int type);
-
-=head1 DESCRIPTION
-
-SSLeay_version() returns a pointer to a constant string describing the
-version of the OpenSSL library or giving information about the library
-build.
-
-The following B<type> values are supported:
-
-=over 4
-
-=item SSLEAY_VERSION
-
-The version of the OpenSSL library including the release date.
-
-=item SSLEAY_CFLAGS
-
-The compiler flags set for the compilation process in the form
-"compiler: ..."  if available or "compiler: information not available"
-otherwise.
-
-=item SSLEAY_BUILT_ON
-
-The date of the build process in the form "built on: ..." if available
-or "built on: date not available" otherwise.
-
-=item SSLEAY_PLATFORM
-
-The "Configure" target of the library build in the form "platform: ..."
-if available or "platform: information not available" otherwise.
-
-=item SSLEAY_DIR
-
-The "OPENSSLDIR" setting of the library build in the form "OPENSSLDIR: "...""
-if available or "OPENSSLDIR: N/A" otherwise.
-
-=back
-
-=head1 RETURN VALUES
-
-The following return values can occur:
-
-=over 4
-
-=item "not available"
-
-An invalid value for B<type> was given.
-
-=item Pointer to constant string
-
-Textual description.
-
-=back
-
-=head1 SEE ALSO
-
-L<crypto(3)>
-
-=cut
diff --git a/doc/ssl/SSL_library_init.pod b/doc/ssl/SSL_library_init.pod
index ab9d05d..d96d3f0 100644
--- a/doc/ssl/SSL_library_init.pod
+++ b/doc/ssl/SSL_library_init.pod
@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-SSL_library_init, OpenSSL_add_ssl_algorithms, SSLeay_add_ssl_algorithms
+SSL_library_init, OpenSSL_add_ssl_algorithms,
 - initialize SSL library by registering algorithms
 
 =head1 SYNOPSIS
@@ -11,14 +11,12 @@ SSL_library_init, OpenSSL_add_ssl_algorithms, SSLeay_add_ssl_algorithms
 
  int SSL_library_init(void);
  #define OpenSSL_add_ssl_algorithms()    SSL_library_init()
- #define SSLeay_add_ssl_algorithms()     SSL_library_init()
 
 =head1 DESCRIPTION
 
 SSL_library_init() registers the available SSL/TLS ciphers and digests.
 
-OpenSSL_add_ssl_algorithms() and SSLeay_add_ssl_algorithms() are synonyms
-for SSL_library_init().
+OpenSSL_add_ssl_algorithms() is a synonym for SSL_library_init().
 
 =head1 NOTES
 
diff --git a/e_os.h b/e_os.h
index 6aa0f73..8a08099 100644
--- a/e_os.h
+++ b/e_os.h
@@ -328,7 +328,6 @@ extern FILE *_imp___iob;
 #   define R_OK        4
 #  endif
 #  define OPENSSL_CONF  "openssl.cnf"
-#  define SSLEAY_CONF   OPENSSL_CONF
 #  define NUL_DEV       "nul"
 #  define RFILE         ".rnd"
 #  ifdef OPENSSL_SYS_WINCE
@@ -361,7 +360,6 @@ extern FILE *_imp___iob;
 #    include <unixlib.h>
 #   endif
 #   define OPENSSL_CONF        "openssl.cnf"
-#   define SSLEAY_CONF         OPENSSL_CONF
 #   define RFILE               ".rnd"
 #   define LIST_SEPARATOR_CHAR ','
 #   define NUL_DEV             "NLA0:"
@@ -412,7 +410,6 @@ extern int kbhit(void);
 #   define _O_TEXT O_TEXT
 #   define _O_BINARY O_BINARY
 #   define OPENSSL_CONF   "openssl.cnf"
-#   define SSLEAY_CONF    OPENSSL_CONF
 #   define RFILE    ".rnd"
 #   define LIST_SEPARATOR_CHAR ';'
 #   define EXIT(n)  { if (n) printf("ERROR: %d\n", (int)n); exit(n); }
@@ -433,14 +430,13 @@ extern int kbhit(void);
 #   endif
 
 #   define OPENSSL_CONF        "openssl.cnf"
-#   define SSLEAY_CONF         OPENSSL_CONF
 #   define RFILE               ".rnd"
 #   define LIST_SEPARATOR_CHAR ':'
 #   define NUL_DEV             "/dev/null"
 #   define EXIT(n)             exit(n)
 #  endif
 
-#  define SSLeay_getpid()       getpid()
+#  define OpenSSL_getpid()       getpid()
 
 # endif
 
@@ -455,8 +451,8 @@ extern int kbhit(void);
       /* windows world */
 
 #   ifdef OPENSSL_NO_SOCK
-#    define SSLeay_Write(a,b,c)       (-1)
-#    define SSLeay_Read(a,b,c)        (-1)
+#    define OpenSSL_Write(a,b,c)       (-1)
+#    define OpenSSL_Read(a,b,c)        (-1)
 #    define SHUTDOWN(fd)              close(fd)
 #    define SHUTDOWN2(fd)             close(fd)
 #   elif !defined(__DJGPP__)
@@ -484,13 +480,13 @@ struct servent *PASCAL getservbyname(const char *, const char *);
 #     define socket(d,t,p)   ((int)socket(d,t,p))
 #     define accept(s,f,l)   ((int)accept(s,f,l))
 #    endif
-#    define SSLeay_Write(a,b,c)       send((a),(b),(c),0)
-#    define SSLeay_Read(a,b,c)        recv((a),(b),(c),0)
+#    define OpenSSL_Write(a,b,c)       send((a),(b),(c),0)
+#    define OpenSSL_Read(a,b,c)        recv((a),(b),(c),0)
 #    define SHUTDOWN(fd)              { shutdown((fd),0); closesocket(fd); }
 #    define SHUTDOWN2(fd)             { shutdown((fd),2); closesocket(fd); }
 #   else
-#    define SSLeay_Write(a,b,c)       write_s(a,b,c,0)
-#    define SSLeay_Read(a,b,c)        read_s(a,b,c)
+#    define OpenSSL_Write(a,b,c)       write_s(a,b,c,0)
+#    define OpenSSL_Read(a,b,c)        read_s(a,b,c)
 #    define SHUTDOWN(fd)              close_s(fd)
 #    define SHUTDOWN2(fd)             close_s(fd)
 #   endif
@@ -513,8 +509,8 @@ struct servent *PASCAL getservbyname(const char *, const char *);
 #   else
 #    include <novsock2.h>
 #   endif
-#   define SSLeay_Write(a,b,c)   send((a),(b),(c),0)
-#   define SSLeay_Read(a,b,c) recv((a),(b),(c),0)
+#   define OpenSSL_Write(a,b,c)   send((a),(b),(c),0)
+#   define OpenSSL_Read(a,b,c) recv((a),(b),(c),0)
 #   define SHUTDOWN(fd)    { shutdown((fd),0); closesocket(fd); }
 #   define SHUTDOWN2(fd)      { shutdown((fd),2); closesocket(fd); }
 
@@ -579,8 +575,8 @@ struct servent *PASCAL getservbyname(const char *, const char *);
 #    endif
 #   endif
 
-#   define SSLeay_Read(a,b,c)     read((a),(b),(c))
-#   define SSLeay_Write(a,b,c)    write((a),(b),(c))
+#   define OpenSSL_Read(a,b,c)     read((a),(b),(c))
+#   define OpenSSL_Write(a,b,c)    write((a),(b),(c))
 #   define SHUTDOWN(fd)    { shutdown((fd),0); closesocket((fd)); }
 #   define SHUTDOWN2(fd)   { shutdown((fd),2); closesocket((fd)); }
 #   ifndef INVALID_SOCKET
diff --git a/engines/e_capi.c b/engines/e_capi.c
index 5256768..a38592b 100644
--- a/engines/e_capi.c
+++ b/engines/e_capi.c
@@ -472,7 +472,7 @@ static int capi_init(ENGINE *e)
 
         /* Setup RSA_METHOD */
         rsa_capi_idx = RSA_get_ex_new_index(0, NULL, NULL, NULL, 0);
-        ossl_rsa_meth = RSA_PKCS1_SSLeay();
+        ossl_rsa_meth = RSA_PKCS1_OpenSSL();
         capi_rsa_method.rsa_pub_enc = ossl_rsa_meth->rsa_pub_enc;
         capi_rsa_method.rsa_pub_dec = ossl_rsa_meth->rsa_pub_dec;
         capi_rsa_method.rsa_mod_exp = ossl_rsa_meth->rsa_mod_exp;
diff --git a/engines/e_gmp.c b/engines/e_gmp.c
index dd72759..7888c2b 100644
--- a/engines/e_gmp.c
+++ b/engines/e_gmp.c
@@ -170,7 +170,7 @@ static int bind_helper(ENGINE *e)
         return 0;
 
 #  ifndef OPENSSL_NO_RSA
-    meth1 = RSA_PKCS1_SSLeay();
+    meth1 = RSA_PKCS1_OpenSSL();
     e_gmp_rsa.rsa_pub_enc = meth1->rsa_pub_enc;
     e_gmp_rsa.rsa_pub_dec = meth1->rsa_pub_dec;
     e_gmp_rsa.rsa_priv_enc = meth1->rsa_priv_enc;
diff --git a/include/openssl/dsa.h b/include/openssl/dsa.h
index 8fd5596..8e69e2e 100644
--- a/include/openssl/dsa.h
+++ b/include/openssl/dsa.h
@@ -58,9 +58,8 @@
 
 /*
  * The DSS routines are based on patches supplied by
- * Steven Schoch <schoch at sheba.arc.nasa.gov>.  He basically did the
- * work and I have just tweaked them a little to fit into my
- * stylistic vision for SSLeay :-) */
+ * Steven Schoch <schoch at sheba.arc.nasa.gov>.
+ */
 
 #ifndef HEADER_DSA_H
 # define HEADER_DSA_H
diff --git a/include/openssl/evp.h b/include/openssl/evp.h
index c60d178..15796c0 100644
--- a/include/openssl/evp.h
+++ b/include/openssl/evp.h
@@ -959,9 +959,6 @@ void OPENSSL_add_all_algorithms_conf(void);
 
 void OpenSSL_add_all_ciphers(void);
 void OpenSSL_add_all_digests(void);
-# define SSLeay_add_all_algorithms() OpenSSL_add_all_algorithms()
-# define SSLeay_add_all_ciphers() OpenSSL_add_all_ciphers()
-# define SSLeay_add_all_digests() OpenSSL_add_all_digests()
 
 int EVP_add_cipher(const EVP_CIPHER *cipher);
 int EVP_add_digest(const EVP_MD *digest);
diff --git a/include/openssl/rand.h b/include/openssl/rand.h
index 0086c07..d7756bb 100644
--- a/include/openssl/rand.h
+++ b/include/openssl/rand.h
@@ -92,7 +92,7 @@ const RAND_METHOD *RAND_get_rand_method(void);
 # ifndef OPENSSL_NO_ENGINE
 int RAND_set_rand_engine(ENGINE *engine);
 # endif
-RAND_METHOD *RAND_SSLeay(void);
+RAND_METHOD *RAND_OpenSSL(void);
 void RAND_cleanup(void);
 int RAND_bytes(unsigned char *buf, int num);
 #ifdef OPENSSL_USE_DEPRECATED
@@ -138,8 +138,8 @@ void ERR_load_RAND_strings(void);
 # define RAND_F_FIPS_SET_PRNG_SEED                        104
 # define RAND_F_FIPS_SET_TEST_MODE                        105
 # define RAND_F_FIPS_X931_SET_DT                          106
+# define RAND_F_RAND_BYTES                                100
 # define RAND_F_RAND_GET_RAND_METHOD                      101
-# define RAND_F_SSLEAY_RAND_BYTES                         100
 
 /* Reason codes. */
 # define RAND_R_NOT_IN_TEST_MODE                          101
diff --git a/include/openssl/rsa.h b/include/openssl/rsa.h
index 9abb2a1..1b3027d 100644
--- a/include/openssl/rsa.h
+++ b/include/openssl/rsa.h
@@ -365,8 +365,8 @@ int RSA_set_method(RSA *rsa, const RSA_METHOD *meth);
 /* This function needs the memory locking malloc callbacks to be installed */
 int RSA_memory_lock(RSA *r);
 
-/* these are the actual SSLeay RSA functions */
-const RSA_METHOD *RSA_PKCS1_SSLeay(void);
+/* these are the actual RSA functions */
+const RSA_METHOD *RSA_PKCS1_OpenSSL(void);
 
 const RSA_METHOD *RSA_null_method(void);
 
diff --git a/include/openssl/ssl.h b/include/openssl/ssl.h
index 2e899cd..6dc88c8 100644
--- a/include/openssl/ssl.h
+++ b/include/openssl/ssl.h
@@ -163,7 +163,7 @@
 extern "C" {
 #endif
 
-/* SSLeay version number for ASN.1 encoding of the session information */
+/* OpenSSL version number for ASN.1 encoding of the session information */
 /*-
  * Version 0 - initial version
  * Version 1 - added the optional peer certificate
@@ -438,20 +438,10 @@ typedef int (*custom_ext_parse_cb) (SSL *s, unsigned int ext_type,
 # define SSL_OP_NO_SSL_MASK (SSL_OP_NO_SSLv3|\
         SSL_OP_NO_TLSv1|SSL_OP_NO_TLSv1_1|SSL_OP_NO_TLSv1_2)
 
-/*
- * These next two were never actually used for anything since SSLeay zap so
- * we have some more flags.
- */
-/*
- * The next flag deliberately changes the ciphertest, this is a check for the
- * PKCS#1 attack
- */
+/* Removed from previous versions */
 # define SSL_OP_PKCS1_CHECK_1                            0x0
 # define SSL_OP_PKCS1_CHECK_2                            0x0
-
-/* Removed as of OpenSSL 1.1.0 */
 # define SSL_OP_NETSCAPE_CA_DN_BUG                       0x0
-/* Removed as of OpenSSL 1.1.0 */
 # define SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG          0x0L
 /*
  * Make server add server-hello extension from early version of cryptopro
@@ -1034,7 +1024,6 @@ size_t SSL_get_peer_finished(const SSL *s, void *buf, size_t count);
 # define SSL_VERIFY_CLIENT_ONCE          0x04
 
 # define OpenSSL_add_ssl_algorithms()    SSL_library_init()
-# define SSLeay_add_ssl_algorithms()     SSL_library_init()
 
 /* More backward compatibility */
 # define SSL_get_cipher(s) \
diff --git a/include/openssl/x509.h b/include/openssl/x509.h
index 21a8c5a..32bec25 100644
--- a/include/openssl/x509.h
+++ b/include/openssl/x509.h
@@ -233,8 +233,7 @@ DECLARE_STACK_OF(X509_TRUST)
 
 # define XN_FLAG_SEP_MASK        (0xf << 16)
 
-# define XN_FLAG_COMPAT          0/* Traditional SSLeay: use old
-                                   * X509_NAME_print */
+# define XN_FLAG_COMPAT          0/* Traditional; use old X509_NAME_print */
 # define XN_FLAG_SEP_COMMA_PLUS  (1 << 16)/* RFC2253 ,+ */
 # define XN_FLAG_SEP_CPLUS_SPC   (2 << 16)/* ,+ spaced: more readable */
 # define XN_FLAG_SEP_SPLUS_SPC   (3 << 16)/* ;+ spaced */
diff --git a/test/recipes/80-test_ca.t b/test/recipes/80-test_ca.t
index f57fb3c..ff6eb65 100644
--- a/test/recipes/80-test_ca.t
+++ b/test/recipes/80-test_ca.t
@@ -21,17 +21,17 @@ remove_tree("demoCA", { safe => 0 });
 
 plan tests => 4;
  SKIP: {
-     $ENV{SSLEAY_CONFIG} = "-config ".top_file("test", "CAss.cnf");
+     $ENV{OPENSSL_CONFIG} = "-config ".top_file("test", "CAss.cnf");
      skip "failed creating CA structure", 3
 	 if !is(system("$perl ".$CA_pl." -newca < ".devnull()." 2>&1"), 0,
 		'creating CA structure');
 
-     $ENV{SSLEAY_CONFIG} = "-config ".top_file("test", "Uss.cnf");
+     $ENV{OPENSSL_CONFIG} = "-config ".top_file("test", "Uss.cnf");
      skip "failed creating new certificate request", 2
 	 if !is(system("$perl ".$CA_pl." -newreq 2>&1"), 0,
 		'creating new certificate request');
 
-     $ENV{SSLEAY_CONFIG} = "-config ".$std_openssl_cnf;
+     $ENV{OPENSSL_CONFIG} = "-config ".$std_openssl_cnf;
      skip "failed to sign certificate request", 1
 	 if !is(yes("$perl ".$CA_pl." -sign 2>&1"), 0,
 		'signing certificate request');
diff --git a/test/recipes/80-test_tsa.t b/test/recipes/80-test_tsa.t
index 171592a..8e02a6b 100644
--- a/test/recipes/80-test_tsa.t
+++ b/test/recipes/80-test_tsa.t
@@ -74,7 +74,7 @@ indir "tsa" => sub
 {
     $ENV{OPENSSL_CONF} = top_file("test", "CAtsa.cnf");
     # Because that's what ../apps/CA.pl really looks at
-    $ENV{SSLEAY_CONFIG} = "-config ".$ENV{OPENSSL_CONF};
+    $ENV{OPENSSL_CONFIG} = "-config ".$ENV{OPENSSL_CONF};
     $ENV{OPENSSL} = cmdstr(app(["openssl"]));
     $testtsa = top_file("test", "recipes", "80-test_tsa.t");
     $CAtsa = top_file("test", "CAtsa.cnf");
diff --git a/util/libeay.num b/util/libeay.num
index 661575f..ddcf594 100755
--- a/util/libeay.num
+++ b/util/libeay.num
@@ -1,5 +1,5 @@
-SSLeay                                  1	EXIST::FUNCTION:
-SSLeay_version                          2	EXIST::FUNCTION:
+OpenSSL_version_num                     1	EXIST::FUNCTION:
+OpenSSL_version                         2	EXIST::FUNCTION:
 ASN1_BIT_STRING_asn1_meth               3	NOEXIST::FUNCTION:
 ASN1_HEADER_free                        4	NOEXIST::FUNCTION:
 ASN1_HEADER_new                         5	NOEXIST::FUNCTION:
@@ -472,7 +472,7 @@ RC4_set_key                             479	EXIST::FUNCTION:RC4
 RSAPrivateKey_asn1_meth                 480	NOEXIST::FUNCTION:
 RSAPrivateKey_dup                       481	EXIST::FUNCTION:RSA
 RSAPublicKey_dup                        482	EXIST::FUNCTION:RSA
-RSA_PKCS1_SSLeay                        483	EXIST::FUNCTION:RSA
+RSA_PKCS1_OpenSSL                       483	EXIST::FUNCTION:RSA
 RSA_free                                484	EXIST::FUNCTION:RSA
 RSA_generate_key                        485	EXIST::FUNCTION:DEPRECATED,RSA
 RSA_new                                 486	EXIST::FUNCTION:RSA
@@ -1082,7 +1082,7 @@ BN_MONT_CTX_copy                        1109	EXIST::FUNCTION:
 BIO_new_socks4a_connect                 1110	NOEXIST::FUNCTION:
 BIO_s_socks4a_connect                   1111	NOEXIST::FUNCTION:
 PROXY_set_connect_mode                  1112	NOEXIST::FUNCTION:
-RAND_SSLeay                             1113	EXIST::FUNCTION:
+RAND_OpenSSL                            1113	EXIST::FUNCTION:
 RAND_set_rand_method                    1114	EXIST::FUNCTION:
 RSA_memory_lock                         1115	EXIST::FUNCTION:RSA
 bn_sub_words                            1116	NOEXIST::FUNCTION:


More information about the openssl-commits mailing list
diff --git a/crypto/rand/md_rand.c b/crypto/rand/md_rand.c
index c7d54ed..0eaaf62 100644
--- a/crypto/rand/md_rand.c
+++ b/crypto/rand/md_rand.c
@@ -166,35 +166,35 @@ int rand_predictable = 0;
 
 static void rand_hw_seed(EVP_MD_CTX *ctx);
 
-static void ssleay_rand_cleanup(void);
-static int ssleay_rand_seed(const void *buf, int num);
-static int ssleay_rand_add(const void *buf, int num, double add_entropy);
-static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo);
-static int ssleay_rand_nopseudo_bytes(unsigned char *buf, int num);
+static void rand_cleanup(void);
+static int rand_seed(const void *buf, int num);
+static int rand_add(const void *buf, int num, double add_entropy);
+static int rand_bytes(unsigned char *buf, int num, int pseudo);
+static int rand_nopseudo_bytes(unsigned char *buf, int num);
 #ifndef OPENSSL_NO_DEPRECATED
-static int ssleay_rand_pseudo_bytes(unsigned char *buf, int num);
+static int rand_pseudo_bytes(unsigned char *buf, int num);
 #endif
-static int ssleay_rand_status(void);
+static int rand_status(void);
 
-static RAND_METHOD rand_ssleay_meth = {
-    ssleay_rand_seed,
-    ssleay_rand_nopseudo_bytes,
-    ssleay_rand_cleanup,
-    ssleay_rand_add,
+static RAND_METHOD rand_meth = {
+    rand_seed,
+    rand_nopseudo_bytes,
+    rand_cleanup,
+    rand_add,
 #ifndef OPENSSL_NO_DEPRECATED
-    ssleay_rand_pseudo_bytes,
+    rand_pseudo_bytes,
 #else
     NULL,
 #endif
-    ssleay_rand_status
+    rand_status
 };
 
-RAND_METHOD *RAND_SSLeay(void)
+RAND_METHOD *RAND_OpenSSL(void)
 {
-    return (&rand_ssleay_meth);
+    return (&rand_meth);
 }
 
-static void ssleay_rand_cleanup(void)
+static void rand_cleanup(void)
 {
     OPENSSL_cleanse(state, sizeof(state));
     state_num = 0;
@@ -206,7 +206,7 @@ static void ssleay_rand_cleanup(void)
     initialized = 0;
 }
 
-static int ssleay_rand_add(const void *buf, int num, double add)
+static int rand_add(const void *buf, int num, double add)
 {
     int i, j, k, st_idx;
     long md_c[2];
@@ -355,12 +355,12 @@ static int ssleay_rand_add(const void *buf, int num, double add)
     return rv;
 }
 
-static int ssleay_rand_seed(const void *buf, int num)
+static int rand_seed(const void *buf, int num)
 {
-    return ssleay_rand_add(buf, num, (double)num);
+    return rand_add(buf, num, (double)num);
 }
 
-static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
+static int rand_bytes(unsigned char *buf, int num, int pseudo)
 {
     static volatile int stirred_pool = 0;
     int i, j, k, st_num, st_idx;
@@ -433,7 +433,7 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
 
     CRYPTO_w_lock(CRYPTO_LOCK_RAND);
 
     /* prevent ssleay_rand_bytes() from trying to obtain the lock again */
     CRYPTO_w_lock(CRYPTO_LOCK_RAND2);
     CRYPTO_THREADID_current(&locking_threadid);
     CRYPTO_w_unlock(CRYPTO_LOCK_RAND2);
@@ -470,7 +470,7 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
          * In the output function only half of 'md' remains secret, so we
          * better make sure that the required entropy gets 'evenly
          * distributed' through 'state', our randomness pool. The input
          * function (ssleay_rand_add) chains all of 'md', which makes it more
          * suitable for this purpose.
          */
 
@@ -482,9 +482,9 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
 #define DUMMY_SEED "...................." /* at least MD_DIGEST_LENGTH */
             /*
              * Note that the seed does not matter, it's just that
              * ssleay_rand_add expects to have something to hash.
              */
-            ssleay_rand_add(DUMMY_SEED, MD_DIGEST_LENGTH, 0.0);
+            rand_add(DUMMY_SEED, MD_DIGEST_LENGTH, 0.0);
             n -= MD_DIGEST_LENGTH;
         }
         if (ok)
@@ -588,34 +588,34 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
     else if (pseudo)
         return 0;
     else {
-        RANDerr(RAND_F_SSLEAY_RAND_BYTES, RAND_R_PRNG_NOT_SEEDED);
+        RANDerr(RAND_F_RAND_BYTES, RAND_R_PRNG_NOT_SEEDED);
         ERR_add_error_data(1, "You need to read the OpenSSL FAQ, "
                            "http://www.openssl.org/support/faq.html");
         return (0);
     }
  err:
     EVP_MD_CTX_cleanup(&m);
-    RANDerr(RAND_F_SSLEAY_RAND_BYTES, ERR_R_EVP_LIB);
+    RANDerr(RAND_F_RAND_BYTES, ERR_R_EVP_LIB);
     return 0;
 
 }
 
-static int ssleay_rand_nopseudo_bytes(unsigned char *buf, int num)
+static int rand_nopseudo_bytes(unsigned char *buf, int num)
 {
-    return ssleay_rand_bytes(buf, num, 0);
+    return rand_bytes(buf, num, 0);
 }
 
 #ifndef OPENSSL_NO_DEPRECATED
 /*
  * pseudo-random bytes that are guaranteed to be unique but not unpredictable
  */
-static int ssleay_rand_pseudo_bytes(unsigned char *buf, int num)
+static int rand_pseudo_bytes(unsigned char *buf, int num)
 {
-    return ssleay_rand_bytes(buf, num, 1);
+    return rand_bytes(buf, num, 1);
 }
 #endif
 
-static int ssleay_rand_status(void)
+static int rand_status(void)
 {
     CRYPTO_THREADID cur;
     int ret;
@@ -637,7 +637,7 @@ static int ssleay_rand_status(void)
         CRYPTO_w_lock(CRYPTO_LOCK_RAND);
 
         /*
          * prevent ssleay_rand_bytes() from trying to obtain the lock again
          */
         CRYPTO_w_lock(CRYPTO_LOCK_RAND2);
         CRYPTO_THREADID_cpy(&locking_threadid, &cur);
@@ -433,7 +433,7 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
     CRYPTO_w_lock(CRYPTO_LOCK_RAND);
 
-    /* prevent ssleay_rand_bytes() from trying to obtain the lock again */
+    /* prevent rand_bytes() from trying to obtain the lock again */
     CRYPTO_w_lock(CRYPTO_LOCK_RAND2);
     CRYPTO_THREADID_current(&locking_threadid);
@@ -470,7 +470,7 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
          * better make sure that the required entropy gets 'evenly
          * distributed' through 'state', our randomness pool. The input
-         * function (ssleay_rand_add) chains all of 'md', which makes it more
+         * function (rand_add) chains all of 'md', which makes it more
          * suitable for this purpose.
          */
@@ -482,9 +482,9 @@ static int ssleay_rand_bytes(unsigned char *buf, int num, int pseudo)
             /*
              * Note that the seed does not matter, it's just that
-             * ssleay_rand_add expects to have something to hash.
+             * rand_add expects to have something to hash.
              */
@@ -637,7 +637,7 @@ static int ssleay_rand_status(void)
 
         /*
-         * prevent ssleay_rand_bytes() from trying to obtain the lock again
+         * prevent rand_bytes() from trying to obtain the lock again
          */
         CRYPTO_w_lock(CRYPTO_LOCK_RAND2);
diff --git a/demos/engines/ibmca/hw_ibmca.c b/demos/engines/ibmca/hw_ibmca.c
index 29f8547..c0f2982 100644
--- a/demos/engines/ibmca/hw_ibmca.c
+++ b/demos/engines/ibmca/hw_ibmca.c
@@ -241,14 +241,14 @@ static int bind_helper(ENGINE *e)
 
 #  ifndef OPENSSL_NO_RSA
     /*
      * We know that the "PKCS1_SSLeay()" functions hook properly to the
      * ibmca-specific mod_exp and mod_exp_crt so we use those functions. NB:
      * We don't use ENGINE_openssl() or anything "more generic" because
      * something like the RSAref code may not hook properly, and if you own
      * one of these cards then you have the right to do RSA operations on it
      * anyway!
      */
-    meth1 = RSA_PKCS1_SSLeay();
+    meth1 = RSA_PKCS1_OpenSSL();
     ibmca_rsa.rsa_pub_enc = meth1->rsa_pub_enc;
     ibmca_rsa.rsa_pub_dec = meth1->rsa_pub_dec;
     ibmca_rsa.rsa_priv_enc = meth1->rsa_priv_enc;
@@ -241,14 +241,14 @@ static int bind_helper(ENGINE *e)
 #  ifndef OPENSSL_NO_RSA
     /*
-     * We know that the "PKCS1_SSLeay()" functions hook properly to the
+     * We know that the "PKCS1_OpenSSL()" functions hook properly to the
      * ibmca-specific mod_exp and mod_exp_crt so we use those functions. NB:
      * We don't use ENGINE_openssl() or anything "more generic" because
diff --git a/demos/engines/zencod/hw_zencod.c b/demos/engines/zencod/hw_zencod.c
index 5f50980..132ece0 100644
--- a/demos/engines/zencod/hw_zencod.c
+++ b/demos/engines/zencod/hw_zencod.c
@@ -309,14 +309,14 @@ static int bind_helper(ENGINE *e)
     }
 #  ifndef OPENSSL_NO_RSA
     /*
      * We know that the "PKCS1_SSLeay()" functions hook properly to the
      * Zencod-specific mod_exp and mod_exp_crt so we use those functions. NB:
      * We don't use ENGINE_openssl() or anything "more generic" because
      * something like the RSAref code may not hook properly, and if you own
      * one of these cards then you have the right to do RSA operations on it
      * anyway!
      */
-    meth_rsa = RSA_PKCS1_SSLeay();
+    meth_rsa = RSA_PKCS1_OpenSSL();
 
     zencod_rsa.rsa_pub_enc = meth_rsa->rsa_pub_enc;
     zencod_rsa.rsa_pub_dec = meth_rsa->rsa_pub_dec;
@@ -358,9 +358,9 @@ static int bind_helper(ENGINE *e)
 #  endif
 
     /*
-     * We use OpenSSL (SSLeay) meth to supply what we don't provide ;-*)
+     * We use OpenSSL meth to supply what we don't provide ;-*)
      */
-    meth_rand = RAND_SSLeay();
+    meth_rand = RAND_OpenSSL();
 
     /* meth_rand->seed ; */
     /* zencod_rand.seed = meth_rand->seed ; */
@@ -776,7 +776,7 @@ static int RSA_zencod_rsa_mod_exp(BIGNUM *r0, const BIGNUM *i, RSA *rsa)
     if (RSA_size(rsa) * 8 > ZENBRIDGE_MAX_KEYSIZE_RSA_CRT) {
         const RSA_METHOD *meth;
 
-        meth = RSA_PKCS1_SSLeay();
+        meth = RSA_PKCS1_OpenSSL();
         return meth->rsa_mod_exp(r0, i, rsa);
     } else {
         zen_nb_t y, x, p, q, dmp1, dmq1, iqmp;
@@ -827,7 +827,7 @@ static int RSA_zencod_bn_mod_exp(BIGNUM *r, const BIGNUM *a, const BIGNUM *p,
     if (BN_num_bits(m) > ZENBRIDGE_MAX_KEYSIZE_RSA) {
         const RSA_METHOD *meth;
 
-        meth = RSA_PKCS1_SSLeay();
+        meth = RSA_PKCS1_OpenSSL();
         return meth->bn_mod_exp(r, a, p, m, ctx, m_ctx);
     } else {
         zen_nb_t y, x, e, n;
@@ -309,14 +309,14 @@ static int bind_helper(ENGINE *e)
 #  ifndef OPENSSL_NO_RSA
     /*
-     * We know that the "PKCS1_SSLeay()" functions hook properly to the
+     * We know that the "PKCS1_OpenSSL()" functions hook properly to the
      * Zencod-specific mod_exp and mod_exp_crt so we use those functions. NB:
      * We don't use ENGINE_openssl() or anything "more generic" because
diff --git a/engines/e_chil.c b/engines/e_chil.c
index 0764c01..54c6b91 100644
--- a/engines/e_chil.c
+++ b/engines/e_chil.c
@@ -376,14 +376,14 @@ static int bind_helper(ENGINE *e)
 
 #  ifndef OPENSSL_NO_RSA
     /*
      * We know that the "PKCS1_SSLeay()" functions hook properly to the
      * cswift-specific mod_exp and mod_exp_crt so we use those functions. NB:
      * We don't use ENGINE_openssl() or anything "more generic" because
      * something like the RSAref code may not hook properly, and if you own
      * one of these cards then you have the right to do RSA operations on it
      * anyway!
      */
-    meth1 = RSA_PKCS1_SSLeay();
+    meth1 = RSA_PKCS1_OpenSSL();
     hwcrhk_rsa.rsa_pub_enc = meth1->rsa_pub_enc;
     hwcrhk_rsa.rsa_pub_dec = meth1->rsa_pub_dec;
     hwcrhk_rsa.rsa_priv_enc = meth1->rsa_priv_enc;
@@ -376,14 +376,14 @@ static int bind_helper(ENGINE *e)
 #  ifndef OPENSSL_NO_RSA
     /*
-     * We know that the "PKCS1_SSLeay()" functions hook properly to the
+     * We know that the "PKCS1_OpenSSL()" functions hook properly to the
      * cswift-specific mod_exp and mod_exp_crt so we use those functions. NB:
      * We don't use ENGINE_openssl() or anything "more generic" because
diff --git a/engines/e_ubsec.c b/engines/e_ubsec.c
index 34be930..ef070b0 100644
--- a/engines/e_ubsec.c
+++ b/engines/e_ubsec.c
@@ -233,14 +233,14 @@ static int bind_helper(ENGINE *e)
 
 #  ifndef OPENSSL_NO_RSA
     /*
      * We know that the "PKCS1_SSLeay()" functions hook properly to the
      * Broadcom-specific mod_exp and mod_exp_crt so we use those functions.
      * NB: We don't use ENGINE_openssl() or anything "more generic" because
      * something like the RSAref code may not hook properly, and if you own
      * one of these cards then you have the right to do RSA operations on it
      * anyway!
      */
-    meth1 = RSA_PKCS1_SSLeay();
+    meth1 = RSA_PKCS1_OpenSSL();
     ubsec_rsa.rsa_pub_enc = meth1->rsa_pub_enc;
     ubsec_rsa.rsa_pub_dec = meth1->rsa_pub_dec;
     ubsec_rsa.rsa_priv_enc = meth1->rsa_priv_enc;
@@ -611,7 +611,7 @@ static int ubsec_rsa_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa,
         /*
          * Do in software as hardware failed.
          */
-        const RSA_METHOD *meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *meth = RSA_PKCS1_OpenSSL();
         to_return = (*meth->rsa_mod_exp) (r0, I, rsa, ctx);
     }
  err:
@@ -679,7 +679,7 @@ static int ubsec_mod_exp_mont(BIGNUM *r, const BIGNUM *a, const BIGNUM *p,
 
     /* Do in software if the key is too large for the hardware. */
     if (BN_num_bits(m) > max_key_len) {
-        const RSA_METHOD *meth = RSA_PKCS1_SSLeay();
+        const RSA_METHOD *meth = RSA_PKCS1_OpenSSL();
         ret = (*meth->bn_mod_exp) (r, a, p, m, ctx, m_ctx);
     } else {
         ret = ubsec_mod_exp(r, a, p, m, ctx);
@@ -978,7 +978,7 @@ static int ubsec_rand_bytes(unsigned char *buf, int num)
         const RAND_METHOD *meth;
         UBSECerr(UBSEC_F_UBSEC_RAND_BYTES, UBSEC_R_UNIT_FAILURE);
         num = p_UBSEC_ubsec_bits_to_bytes(num);
-        meth = RAND_SSLeay();
+        meth = RAND_OpenSSL();
         meth->seed(buf, num);
         ret = meth->bytes(buf, num);
         goto err;
@@ -994,7 +994,7 @@ static int ubsec_rand_bytes(unsigned char *buf, int num)
         p_UBSEC_ubsec_close(fd);
 
         num = p_UBSEC_ubsec_bits_to_bytes(num);
-        meth = RAND_SSLeay();
+        meth = RAND_OpenSSL();
         meth->seed(buf, num);
         ret = meth->bytes(buf, num);
 
@@ -233,14 +233,14 @@ static int bind_helper(ENGINE *e)
 #  ifndef OPENSSL_NO_RSA
     /*
-     * We know that the "PKCS1_SSLeay()" functions hook properly to the
+     * We know that the "PKCS1_OpenSSL()" functions hook properly to the
      * Broadcom-specific mod_exp and mod_exp_crt so we use those functions.
      * NB: We don't use ENGINE_openssl() or anything "more generic" because
diff --git a/include/openssl/crypto.h b/include/openssl/crypto.h
index 56afc51..5d15515 100644
--- a/include/openssl/crypto.h
+++ b/include/openssl/crypto.h
@@ -145,19 +145,6 @@
 extern "C" {
 #endif
 
-/* Backward compatibility to SSLeay */
-/*
- * This is more to be used to check the correct DLL is being used in the MS
- * world.
- */
-# define SSLEAY_VERSION_NUMBER   OPENSSL_VERSION_NUMBER
-# define SSLEAY_VERSION          0
-/* #define SSLEAY_OPTIONS       1 no longer supported */
-# define SSLEAY_CFLAGS           2
-# define SSLEAY_BUILT_ON         3
-# define SSLEAY_PLATFORM         4
-# define SSLEAY_DIR              5
-
 /*
  * When changing the CRYPTO_LOCK_* list, be sure to maintin the text lock
  * names in cryptlib.c
@@ -243,7 +230,7 @@ typedef struct {
 } CRYPTO_dynlock;
 
 /*
  * The following can be used to detect memory leaks in the SSLeay library. It
  * used, it turns on malloc checking
  */
 
@@ -350,8 +337,13 @@ int CRYPTO_is_mem_check_on(void);
 
 # define OPENSSL_MALLOC_MAX_NELEMS(type)  (((1U<<(sizeof(int)*8-1))-1)/sizeof(type))
 
-const char *SSLeay_version(int type);
-unsigned long SSLeay(void);
+unsigned long OpenSSL_version_num(void);
+const char *OpenSSL_version(int type);
+# define OPENSSL_VERSION          0
+# define OPENSSL_CFLAGS           1
+# define OPENSSL_BUILT_ON         2
+# define OPENSSL_PLATFORM         3
+# define OPENSSL_DIR              4
 
 int OPENSSL_issetugid(void);
 
@@ -243,7 +230,7 @@ typedef struct {
 
 /*
- * The following can be used to detect memory leaks in the SSLeay library. It
+ * The following can be used to detect memory leaks in the OpenSSL library. It
  * used, it turns on malloc checking
  */